#-*- coding: utf-8 -*-
# Generated from swedish.sbl by Snowball 3.0.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class SwedishStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from swedish.sbl by Snowball 3.0.1 - https://snowballstem.org/
    '''

    g_v = {u"a", u"e", u"i", u"o", u"u", u"y", u"ä", u"å", u"ö"}

    g_s_ending = {u"b", u"c", u"d", u"f", u"g", u"h", u"j", u"k", u"l", u"m", u"n", u"o", u"p", u"r", u"t", u"v", u"y"}

    g_ost_ending = {u"i", u"k", u"l", u"n", u"p", u"r", u"t", u"u", u"v"}

    I_x = 0
    I_p1 = 0

    def __r_mark_regions(self):
        self.I_p1 = self.limit
        v_1 = self.cursor
        c = self.cursor + 3
        if c > self.limit:
            return False
        self.cursor = c
        self.I_x = self.cursor
        self.cursor = v_1
        if not self.go_out_grouping(SwedishStemmer.g_v):
            return False
        self.cursor += 1
        if not self.go_in_grouping(SwedishStemmer.g_v):
            return False
        self.cursor += 1
        self.I_p1 = self.cursor
        try:
            if self.I_p1 >= self.I_x:
                raise lab0()
            self.I_p1 = self.I_x
        except lab0: pass
        return True

    def __r_et_condition(self):
        v_1 = self.limit - self.cursor
        if not self.out_grouping_b(SwedishStemmer.g_v):
            return False
        if not self.in_grouping_b(SwedishStemmer.g_v):
            return False
        try:
            if self.cursor > self.limit_backward:
                raise lab0()
            return False
        except lab0: pass
        self.cursor = self.limit - v_1
        v_3 = self.limit - self.cursor
        try:
            if self.find_among_b(SwedishStemmer.a_0) == 0:
                raise lab1()
            return False
        except lab1: pass
        self.cursor = self.limit - v_3
        return True

    def __r_main_suffix(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(SwedishStemmer.a_1)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.slice_del():
                return False

        elif among_var == 2:
            try:
                v_3 = self.limit - self.cursor
                try:
                    if not self.eq_s_b(u"et"):
                        raise lab1()
                    if not self.__r_et_condition():
                        raise lab1()
                    self.bra = self.cursor
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_3
                if not self.in_grouping_b(SwedishStemmer.g_s_ending):
                    return False
            except lab0: pass
            if not self.slice_del():
                return False

        else:
            if not self.__r_et_condition():
                return False
            if not self.slice_del():
                return False

        return True

    def __r_consonant_pair(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        v_3 = self.limit - self.cursor
        if self.find_among_b(SwedishStemmer.a_2) == 0:
            self.limit_backward = v_2
            return False
        self.cursor = self.limit - v_3
        self.ket = self.cursor
        if self.cursor <= self.limit_backward:
            self.limit_backward = v_2
            return False
        self.cursor -= 1
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.limit_backward = v_2
        return True

    def __r_other_suffix(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(SwedishStemmer.a_3)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.slice_del():
                return False

        elif among_var == 2:
            if not self.in_grouping_b(SwedishStemmer.g_ost_ending):
                return False
            if not self.slice_from(u"ös"):
                return False
        else:
            if not self.slice_from(u"full"):
                return False
        return True

    def _stem(self):
        v_1 = self.cursor
        self.__r_mark_regions()
        self.cursor = v_1
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_2 = self.limit - self.cursor
        self.__r_main_suffix()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_consonant_pair()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_other_suffix()
        self.cursor = self.limit - v_4
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among(u"fab", -1, -1),
        Among(u"h", -1, -1),
        Among(u"pak", -1, -1),
        Among(u"rak", -1, -1),
        Among(u"stak", -1, -1),
        Among(u"kom", -1, -1),
        Among(u"iet", -1, -1),
        Among(u"cit", -1, -1),
        Among(u"dit", -1, -1),
        Among(u"alit", -1, -1),
        Among(u"ilit", -1, -1),
        Among(u"mit", -1, -1),
        Among(u"nit", -1, -1),
        Among(u"pit", -1, -1),
        Among(u"rit", -1, -1),
        Among(u"sit", -1, -1),
        Among(u"tit", -1, -1),
        Among(u"uit", -1, -1),
        Among(u"ivit", -1, -1),
        Among(u"kvit", -1, -1),
        Among(u"xit", -1, -1)
    ]

    a_1 = [
        Among(u"a", -1, 1),
        Among(u"arna", 0, 1),
        Among(u"erna", 0, 1),
        Among(u"heterna", 2, 1),
        Among(u"orna", 0, 1),
        Among(u"ad", -1, 1),
        Among(u"e", -1, 1),
        Among(u"ade", 6, 1),
        Among(u"ande", 6, 1),
        Among(u"arne", 6, 1),
        Among(u"are", 6, 1),
        Among(u"aste", 6, 1),
        Among(u"en", -1, 1),
        Among(u"anden", 12, 1),
        Among(u"aren", 12, 1),
        Among(u"heten", 12, 1),
        Among(u"ern", -1, 1),
        Among(u"ar", -1, 1),
        Among(u"er", -1, 1),
        Among(u"heter", 18, 1),
        Among(u"or", -1, 1),
        Among(u"s", -1, 2),
        Among(u"as", 21, 1),
        Among(u"arnas", 22, 1),
        Among(u"ernas", 22, 1),
        Among(u"ornas", 22, 1),
        Among(u"es", 21, 1),
        Among(u"ades", 26, 1),
        Among(u"andes", 26, 1),
        Among(u"ens", 21, 1),
        Among(u"arens", 29, 1),
        Among(u"hetens", 29, 1),
        Among(u"erns", 21, 1),
        Among(u"at", -1, 1),
        Among(u"et", -1, 3),
        Among(u"andet", 34, 1),
        Among(u"het", 34, 1),
        Among(u"ast", -1, 1)
    ]

    a_2 = [
        Among(u"dd", -1, -1),
        Among(u"gd", -1, -1),
        Among(u"nn", -1, -1),
        Among(u"dt", -1, -1),
        Among(u"gt", -1, -1),
        Among(u"kt", -1, -1),
        Among(u"tt", -1, -1)
    ]

    a_3 = [
        Among(u"ig", -1, 1),
        Among(u"lig", 0, 1),
        Among(u"els", -1, 1),
        Among(u"fullt", -1, 3),
        Among(u"öst", -1, 2)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass



#-*- coding: utf-8 -*-
# Generated from estonian.sbl by Snowball 3.0.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class EstonianStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from estonian.sbl by Snowball 3.0.1 - https://snowballstem.org/
    '''

    g_V1 = {u"a", u"e", u"i", u"o", u"u", u"õ", u"ä", u"ö", u"ü"}

    g_RV = {u"a", u"e", u"i", u"u", u"o"}

    g_KI = {u"k", u"p", u"t", u"g", u"b", u"d", u"s", u"h", u"f", u"š", u"z", u"ž"}

    g_GI = {u"c", u"j", u"l", u"m", u"n", u"q", u"r", u"v", u"w", u"x", u"a", u"e", u"i", u"o", u"u", u"õ", u"ä", u"ö", u"ü"}

    I_p1 = 0

    def __r_mark_regions(self):
        self.I_p1 = self.limit
        if not self.go_out_grouping(EstonianStemmer.g_V1):
            return False
        self.cursor += 1
        if not self.go_in_grouping(EstonianStemmer.g_V1):
            return False
        self.cursor += 1
        self.I_p1 = self.cursor
        return True

    def __r_emphasis(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_0)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        v_3 = self.limit - self.cursor
        c = self.cursor - 4
        if c < self.limit_backward:
            return False
        self.cursor = c
        self.cursor = self.limit - v_3
        if among_var == 1:
            v_4 = self.limit - self.cursor
            if not self.in_grouping_b(EstonianStemmer.g_GI):
                return False
            self.cursor = self.limit - v_4
            v_5 = self.limit - self.cursor
            try:
                if not self.__r_LONGV():
                    raise lab0()
                return False
            except lab0: pass
            self.cursor = self.limit - v_5
            if not self.slice_del():
                return False

        else:
            if not self.in_grouping_b(EstonianStemmer.g_KI):
                return False
            if not self.slice_del():
                return False

        return True

    def __r_verb(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_1)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.slice_del():
                return False

        elif among_var == 2:
            if not self.slice_from(u"a"):
                return False
        else:
            if not self.in_grouping_b(EstonianStemmer.g_V1):
                return False
            if not self.slice_del():
                return False

        return True

    def __r_LONGV(self):
        if self.find_among_b(EstonianStemmer.a_2) == 0:
            return False
        return True

    def __r_i_plural(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        if self.find_among_b(EstonianStemmer.a_3) == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if not self.in_grouping_b(EstonianStemmer.g_RV):
            return False
        if not self.slice_del():
            return False

        return True

    def __r_special_noun_endings(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_4)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.slice_from(u"lase"):
                return False
        elif among_var == 2:
            if not self.slice_from(u"mise"):
                return False
        else:
            if not self.slice_from(u"lise"):
                return False
        return True

    def __r_case_ending(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_5)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            try:
                v_3 = self.limit - self.cursor
                try:
                    if not self.in_grouping_b(EstonianStemmer.g_RV):
                        raise lab1()
                    raise lab0()
                except lab1: pass
                self.cursor = self.limit - v_3
                if not self.__r_LONGV():
                    return False
            except lab0: pass
        else:
            v_4 = self.limit - self.cursor
            c = self.cursor - 4
            if c < self.limit_backward:
                return False
            self.cursor = c
            self.cursor = self.limit - v_4
        if not self.slice_del():
            return False

        return True

    def __r_plural_three_first_cases(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_7)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.slice_from(u"iku"):
                return False
        elif among_var == 2:
            v_3 = self.limit - self.cursor
            try:
                if not self.__r_LONGV():
                    raise lab0()
                return False
            except lab0: pass
            self.cursor = self.limit - v_3
            if not self.slice_del():
                return False

        elif among_var == 3:
            try:
                v_4 = self.limit - self.cursor
                try:
                    v_5 = self.limit - self.cursor
                    c = self.cursor - 4
                    if c < self.limit_backward:
                        raise lab2()
                    self.cursor = c
                    self.cursor = self.limit - v_5
                    among_var = self.find_among_b(EstonianStemmer.a_6)
                    if among_var == 1:
                        if not self.slice_from(u"e"):
                            return False
                    elif among_var == 2:
                        if not self.slice_del():
                            return False

                    raise lab1()
                except lab2: pass
                self.cursor = self.limit - v_4
                if not self.slice_from(u"t"):
                    return False
            except lab1: pass
        else:
            try:
                v_6 = self.limit - self.cursor
                try:
                    if not self.in_grouping_b(EstonianStemmer.g_RV):
                        raise lab4()
                    raise lab3()
                except lab4: pass
                self.cursor = self.limit - v_6
                if not self.__r_LONGV():
                    return False
            except lab3: pass
            if not self.slice_del():
                return False

        return True

    def __r_nu(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        if self.find_among_b(EstonianStemmer.a_8) == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if not self.slice_del():
            return False

        return True

    def __r_undouble_kpt(self):
        if not self.in_grouping_b(EstonianStemmer.g_V1):
            return False
        if self.I_p1 > self.cursor:
            return False
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_9)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.slice_from(u"k"):
                return False
        elif among_var == 2:
            if not self.slice_from(u"p"):
                return False
        else:
            if not self.slice_from(u"t"):
                return False
        return True

    def __r_degrees(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(EstonianStemmer.a_10)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.in_grouping_b(EstonianStemmer.g_RV):
                return False
            if not self.slice_del():
                return False

        else:
            if not self.slice_del():
                return False

        return True

    def __r_substantive(self):
        v_1 = self.limit - self.cursor
        self.__r_special_noun_endings()
        self.cursor = self.limit - v_1
        v_2 = self.limit - self.cursor
        self.__r_case_ending()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_plural_three_first_cases()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_degrees()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_i_plural()
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        self.__r_nu()
        self.cursor = self.limit - v_6
        return True

    def __r_verb_exceptions(self):
        self.bra = self.cursor
        among_var = self.find_among(EstonianStemmer.a_11)
        if among_var == 0:
            return False
        self.ket = self.cursor
        if self.cursor < self.limit:
            return False
        if among_var == 1:
            if not self.slice_from(u"joo"):
                return False
        elif among_var == 2:
            if not self.slice_from(u"saa"):
                return False
        elif among_var == 3:
            if not self.slice_from(u"viima"):
                return False
        elif among_var == 4:
            if not self.slice_from(u"keesi"):
                return False
        elif among_var == 5:
            if not self.slice_from(u"löö"):
                return False
        elif among_var == 6:
            if not self.slice_from(u"lõi"):
                return False
        elif among_var == 7:
            if not self.slice_from(u"loo"):
                return False
        elif among_var == 8:
            if not self.slice_from(u"käisi"):
                return False
        elif among_var == 9:
            if not self.slice_from(u"söö"):
                return False
        elif among_var == 10:
            if not self.slice_from(u"too"):
                return False
        elif among_var == 11:
            if not self.slice_from(u"võisi"):
                return False
        elif among_var == 12:
            if not self.slice_from(u"jääma"):
                return False
        elif among_var == 13:
            if not self.slice_from(u"müüsi"):
                return False
        elif among_var == 14:
            if not self.slice_from(u"luge"):
                return False
        elif among_var == 15:
            if not self.slice_from(u"põde"):
                return False
        elif among_var == 16:
            if not self.slice_from(u"ladu"):
                return False
        elif among_var == 17:
            if not self.slice_from(u"tegi"):
                return False
        else:
            if not self.slice_from(u"nägi"):
                return False
        return True

    def _stem(self):
        v_1 = self.cursor
        try:
            if not self.__r_verb_exceptions():
                raise lab0()
            return False
        except lab0: pass
        self.cursor = v_1
        v_2 = self.cursor
        self.__r_mark_regions()
        self.cursor = v_2
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_3 = self.limit - self.cursor
        self.__r_emphasis()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        try:
            try:
                v_5 = self.limit - self.cursor
                try:
                    if not self.__r_verb():
                        raise lab3()
                    raise lab2()
                except lab3: pass
                self.cursor = self.limit - v_5
                self.__r_substantive()
            except lab2: pass
        except lab1: pass
        self.cursor = self.limit - v_4
        v_6 = self.limit - self.cursor
        self.__r_undouble_kpt()
        self.cursor = self.limit - v_6
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among(u"gi", -1, 1),
        Among(u"ki", -1, 2)
    ]

    a_1 = [
        Among(u"da", -1, 3),
        Among(u"mata", -1, 1),
        Among(u"b", -1, 3),
        Among(u"ksid", -1, 1),
        Among(u"nuksid", 3, 1),
        Among(u"me", -1, 3),
        Among(u"sime", 5, 1),
        Among(u"ksime", 6, 1),
        Among(u"nuksime", 7, 1),
        Among(u"akse", -1, 2),
        Among(u"dakse", 9, 1),
        Among(u"takse", 9, 1),
        Among(u"site", -1, 1),
        Among(u"ksite", 12, 1),
        Among(u"nuksite", 13, 1),
        Among(u"n", -1, 3),
        Among(u"sin", 15, 1),
        Among(u"ksin", 16, 1),
        Among(u"nuksin", 17, 1),
        Among(u"daks", -1, 1),
        Among(u"taks", -1, 1)
    ]

    a_2 = [
        Among(u"aa", -1, -1),
        Among(u"ee", -1, -1),
        Among(u"ii", -1, -1),
        Among(u"oo", -1, -1),
        Among(u"uu", -1, -1),
        Among(u"ää", -1, -1),
        Among(u"õõ", -1, -1),
        Among(u"öö", -1, -1),
        Among(u"üü", -1, -1)
    ]

    a_3 = [
        Among(u"i", -1, 1)
    ]

    a_4 = [
        Among(u"lane", -1, 1),
        Among(u"line", -1, 3),
        Among(u"mine", -1, 2),
        Among(u"lasse", -1, 1),
        Among(u"lisse", -1, 3),
        Among(u"misse", -1, 2),
        Among(u"lasi", -1, 1),
        Among(u"lisi", -1, 3),
        Among(u"misi", -1, 2),
        Among(u"last", -1, 1),
        Among(u"list", -1, 3),
        Among(u"mist", -1, 2)
    ]

    a_5 = [
        Among(u"ga", -1, 1),
        Among(u"ta", -1, 1),
        Among(u"le", -1, 1),
        Among(u"sse", -1, 1),
        Among(u"l", -1, 1),
        Among(u"s", -1, 1),
        Among(u"ks", 5, 1),
        Among(u"t", -1, 2),
        Among(u"lt", 7, 1),
        Among(u"st", 7, 1)
    ]

    a_6 = [
        Among(u"", -1, 2),
        Among(u"las", 0, 1),
        Among(u"lis", 0, 1),
        Among(u"mis", 0, 1),
        Among(u"t", 0, -1)
    ]

    a_7 = [
        Among(u"d", -1, 4),
        Among(u"sid", 0, 2),
        Among(u"de", -1, 4),
        Among(u"ikkude", 2, 1),
        Among(u"ike", -1, 1),
        Among(u"ikke", -1, 1),
        Among(u"te", -1, 3)
    ]

    a_8 = [
        Among(u"va", -1, -1),
        Among(u"du", -1, -1),
        Among(u"nu", -1, -1),
        Among(u"tu", -1, -1)
    ]

    a_9 = [
        Among(u"kk", -1, 1),
        Among(u"pp", -1, 2),
        Among(u"tt", -1, 3)
    ]

    a_10 = [
        Among(u"ma", -1, 2),
        Among(u"mai", -1, 1),
        Among(u"m", -1, 1)
    ]

    a_11 = [
        Among(u"joob", -1, 1),
        Among(u"jood", -1, 1),
        Among(u"joodakse", 1, 1),
        Among(u"jooma", -1, 1),
        Among(u"joomata", 3, 1),
        Among(u"joome", -1, 1),
        Among(u"joon", -1, 1),
        Among(u"joote", -1, 1),
        Among(u"joovad", -1, 1),
        Among(u"juua", -1, 1),
        Among(u"juuakse", 9, 1),
        Among(u"jäi", -1, 12),
        Among(u"jäid", 11, 12),
        Among(u"jäime", 11, 12),
        Among(u"jäin", 11, 12),
        Among(u"jäite", 11, 12),
        Among(u"jääb", -1, 12),
        Among(u"jääd", -1, 12),
        Among(u"jääda", 17, 12),
        Among(u"jäädakse", 18, 12),
        Among(u"jäädi", 17, 12),
        Among(u"jääks", -1, 12),
        Among(u"jääksid", 21, 12),
        Among(u"jääksime", 21, 12),
        Among(u"jääksin", 21, 12),
        Among(u"jääksite", 21, 12),
        Among(u"jääma", -1, 12),
        Among(u"jäämata", 26, 12),
        Among(u"jääme", -1, 12),
        Among(u"jään", -1, 12),
        Among(u"jääte", -1, 12),
        Among(u"jäävad", -1, 12),
        Among(u"jõi", -1, 1),
        Among(u"jõid", 32, 1),
        Among(u"jõime", 32, 1),
        Among(u"jõin", 32, 1),
        Among(u"jõite", 32, 1),
        Among(u"keeb", -1, 4),
        Among(u"keed", -1, 4),
        Among(u"keedakse", 38, 4),
        Among(u"keeks", -1, 4),
        Among(u"keeksid", 40, 4),
        Among(u"keeksime", 40, 4),
        Among(u"keeksin", 40, 4),
        Among(u"keeksite", 40, 4),
        Among(u"keema", -1, 4),
        Among(u"keemata", 45, 4),
        Among(u"keeme", -1, 4),
        Among(u"keen", -1, 4),
        Among(u"kees", -1, 4),
        Among(u"keeta", -1, 4),
        Among(u"keete", -1, 4),
        Among(u"keevad", -1, 4),
        Among(u"käia", -1, 8),
        Among(u"käiakse", 53, 8),
        Among(u"käib", -1, 8),
        Among(u"käid", -1, 8),
        Among(u"käidi", 56, 8),
        Among(u"käiks", -1, 8),
        Among(u"käiksid", 58, 8),
        Among(u"käiksime", 58, 8),
        Among(u"käiksin", 58, 8),
        Among(u"käiksite", 58, 8),
        Among(u"käima", -1, 8),
        Among(u"käimata", 63, 8),
        Among(u"käime", -1, 8),
        Among(u"käin", -1, 8),
        Among(u"käis", -1, 8),
        Among(u"käite", -1, 8),
        Among(u"käivad", -1, 8),
        Among(u"laob", -1, 16),
        Among(u"laod", -1, 16),
        Among(u"laoks", -1, 16),
        Among(u"laoksid", 72, 16),
        Among(u"laoksime", 72, 16),
        Among(u"laoksin", 72, 16),
        Among(u"laoksite", 72, 16),
        Among(u"laome", -1, 16),
        Among(u"laon", -1, 16),
        Among(u"laote", -1, 16),
        Among(u"laovad", -1, 16),
        Among(u"loeb", -1, 14),
        Among(u"loed", -1, 14),
        Among(u"loeks", -1, 14),
        Among(u"loeksid", 83, 14),
        Among(u"loeksime", 83, 14),
        Among(u"loeksin", 83, 14),
        Among(u"loeksite", 83, 14),
        Among(u"loeme", -1, 14),
        Among(u"loen", -1, 14),
        Among(u"loete", -1, 14),
        Among(u"loevad", -1, 14),
        Among(u"loob", -1, 7),
        Among(u"lood", -1, 7),
        Among(u"loodi", 93, 7),
        Among(u"looks", -1, 7),
        Among(u"looksid", 95, 7),
        Among(u"looksime", 95, 7),
        Among(u"looksin", 95, 7),
        Among(u"looksite", 95, 7),
        Among(u"looma", -1, 7),
        Among(u"loomata", 100, 7),
        Among(u"loome", -1, 7),
        Among(u"loon", -1, 7),
        Among(u"loote", -1, 7),
        Among(u"loovad", -1, 7),
        Among(u"luua", -1, 7),
        Among(u"luuakse", 106, 7),
        Among(u"lõi", -1, 6),
        Among(u"lõid", 108, 6),
        Among(u"lõime", 108, 6),
        Among(u"lõin", 108, 6),
        Among(u"lõite", 108, 6),
        Among(u"lööb", -1, 5),
        Among(u"lööd", -1, 5),
        Among(u"löödakse", 114, 5),
        Among(u"löödi", 114, 5),
        Among(u"lööks", -1, 5),
        Among(u"lööksid", 117, 5),
        Among(u"lööksime", 117, 5),
        Among(u"lööksin", 117, 5),
        Among(u"lööksite", 117, 5),
        Among(u"lööma", -1, 5),
        Among(u"löömata", 122, 5),
        Among(u"lööme", -1, 5),
        Among(u"löön", -1, 5),
        Among(u"lööte", -1, 5),
        Among(u"löövad", -1, 5),
        Among(u"lüüa", -1, 5),
        Among(u"lüüakse", 128, 5),
        Among(u"müüa", -1, 13),
        Among(u"müüakse", 130, 13),
        Among(u"müüb", -1, 13),
        Among(u"müüd", -1, 13),
        Among(u"müüdi", 133, 13),
        Among(u"müüks", -1, 13),
        Among(u"müüksid", 135, 13),
        Among(u"müüksime", 135, 13),
        Among(u"müüksin", 135, 13),
        Among(u"müüksite", 135, 13),
        Among(u"müüma", -1, 13),
        Among(u"müümata", 140, 13),
        Among(u"müüme", -1, 13),
        Among(u"müün", -1, 13),
        Among(u"müüs", -1, 13),
        Among(u"müüte", -1, 13),
        Among(u"müüvad", -1, 13),
        Among(u"näeb", -1, 18),
        Among(u"näed", -1, 18),
        Among(u"näeks", -1, 18),
        Among(u"näeksid", 149, 18),
        Among(u"näeksime", 149, 18),
        Among(u"näeksin", 149, 18),
        Among(u"näeksite", 149, 18),
        Among(u"näeme", -1, 18),
        Among(u"näen", -1, 18),
        Among(u"näete", -1, 18),
        Among(u"näevad", -1, 18),
        Among(u"nägema", -1, 18),
        Among(u"nägemata", 158, 18),
        Among(u"näha", -1, 18),
        Among(u"nähakse", 160, 18),
        Among(u"nähti", -1, 18),
        Among(u"põeb", -1, 15),
        Among(u"põed", -1, 15),
        Among(u"põeks", -1, 15),
        Among(u"põeksid", 165, 15),
        Among(u"põeksime", 165, 15),
        Among(u"põeksin", 165, 15),
        Among(u"põeksite", 165, 15),
        Among(u"põeme", -1, 15),
        Among(u"põen", -1, 15),
        Among(u"põete", -1, 15),
        Among(u"põevad", -1, 15),
        Among(u"saab", -1, 2),
        Among(u"saad", -1, 2),
        Among(u"saada", 175, 2),
        Among(u"saadakse", 176, 2),
        Among(u"saadi", 175, 2),
        Among(u"saaks", -1, 2),
        Among(u"saaksid", 179, 2),
        Among(u"saaksime", 179, 2),
        Among(u"saaksin", 179, 2),
        Among(u"saaksite", 179, 2),
        Among(u"saama", -1, 2),
        Among(u"saamata", 184, 2),
        Among(u"saame", -1, 2),
        Among(u"saan", -1, 2),
        Among(u"saate", -1, 2),
        Among(u"saavad", -1, 2),
        Among(u"sai", -1, 2),
        Among(u"said", 190, 2),
        Among(u"saime", 190, 2),
        Among(u"sain", 190, 2),
        Among(u"saite", 190, 2),
        Among(u"sõi", -1, 9),
        Among(u"sõid", 195, 9),
        Among(u"sõime", 195, 9),
        Among(u"sõin", 195, 9),
        Among(u"sõite", 195, 9),
        Among(u"sööb", -1, 9),
        Among(u"sööd", -1, 9),
        Among(u"söödakse", 201, 9),
        Among(u"söödi", 201, 9),
        Among(u"sööks", -1, 9),
        Among(u"sööksid", 204, 9),
        Among(u"sööksime", 204, 9),
        Among(u"sööksin", 204, 9),
        Among(u"sööksite", 204, 9),
        Among(u"sööma", -1, 9),
        Among(u"söömata", 209, 9),
        Among(u"sööme", -1, 9),
        Among(u"söön", -1, 9),
        Among(u"sööte", -1, 9),
        Among(u"söövad", -1, 9),
        Among(u"süüa", -1, 9),
        Among(u"süüakse", 215, 9),
        Among(u"teeb", -1, 17),
        Among(u"teed", -1, 17),
        Among(u"teeks", -1, 17),
        Among(u"teeksid", 219, 17),
        Among(u"teeksime", 219, 17),
        Among(u"teeksin", 219, 17),
        Among(u"teeksite", 219, 17),
        Among(u"teeme", -1, 17),
        Among(u"teen", -1, 17),
        Among(u"teete", -1, 17),
        Among(u"teevad", -1, 17),
        Among(u"tegema", -1, 17),
        Among(u"tegemata", 228, 17),
        Among(u"teha", -1, 17),
        Among(u"tehakse", 230, 17),
        Among(u"tehti", -1, 17),
        Among(u"toob", -1, 10),
        Among(u"tood", -1, 10),
        Among(u"toodi", 234, 10),
        Among(u"tooks", -1, 10),
        Among(u"tooksid", 236, 10),
        Among(u"tooksime", 236, 10),
        Among(u"tooksin", 236, 10),
        Among(u"tooksite", 236, 10),
        Among(u"tooma", -1, 10),
        Among(u"toomata", 241, 10),
        Among(u"toome", -1, 10),
        Among(u"toon", -1, 10),
        Among(u"toote", -1, 10),
        Among(u"toovad", -1, 10),
        Among(u"tuua", -1, 10),
        Among(u"tuuakse", 247, 10),
        Among(u"tõi", -1, 10),
        Among(u"tõid", 249, 10),
        Among(u"tõime", 249, 10),
        Among(u"tõin", 249, 10),
        Among(u"tõite", 249, 10),
        Among(u"viia", -1, 3),
        Among(u"viiakse", 254, 3),
        Among(u"viib", -1, 3),
        Among(u"viid", -1, 3),
        Among(u"viidi", 257, 3),
        Among(u"viiks", -1, 3),
        Among(u"viiksid", 259, 3),
        Among(u"viiksime", 259, 3),
        Among(u"viiksin", 259, 3),
        Among(u"viiksite", 259, 3),
        Among(u"viima", -1, 3),
        Among(u"viimata", 264, 3),
        Among(u"viime", -1, 3),
        Among(u"viin", -1, 3),
        Among(u"viisime", -1, 3),
        Among(u"viisin", -1, 3),
        Among(u"viisite", -1, 3),
        Among(u"viite", -1, 3),
        Among(u"viivad", -1, 3),
        Among(u"võib", -1, 11),
        Among(u"võid", -1, 11),
        Among(u"võida", 274, 11),
        Among(u"võidakse", 275, 11),
        Among(u"võidi", 274, 11),
        Among(u"võiks", -1, 11),
        Among(u"võiksid", 278, 11),
        Among(u"võiksime", 278, 11),
        Among(u"võiksin", 278, 11),
        Among(u"võiksite", 278, 11),
        Among(u"võima", -1, 11),
        Among(u"võimata", 283, 11),
        Among(u"võime", -1, 11),
        Among(u"võin", -1, 11),
        Among(u"võis", -1, 11),
        Among(u"võite", -1, 11),
        Among(u"võivad", -1, 11)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass



#-*- coding: utf-8 -*-
# Generated from armenian.sbl by Snowball 3.0.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class ArmenianStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from armenian.sbl by Snowball 3.0.1 - https://snowballstem.org/
    '''

    g_v = {u"ա", u"է", u"ի", u"օ", u"ւ", u"ե", u"ո", u"ը"}

    I_p2 = 0
    I_pV = 0

    def __r_mark_regions(self):
        self.I_pV = self.limit
        self.I_p2 = self.limit
        v_1 = self.cursor
        try:
            if not self.go_out_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_pV = self.cursor
            if not self.go_in_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_out_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_in_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_p2 = self.cursor
        except lab0: pass
        self.cursor = v_1
        return True

    def __r_R2(self):
        return self.I_p2 <= self.cursor

    def __r_adjective(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_0) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        return True

    def __r_verb(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_1) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        return True

    def __r_noun(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_2) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        return True

    def __r_ending(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_3) == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R2():
            return False
        if not self.slice_del():
            return False

        return True

    def _stem(self):
        self.__r_mark_regions()
        self.limit_backward = self.cursor
        self.cursor = self.limit
        if self.cursor < self.I_pV:
            return False
        v_3 = self.limit_backward
        self.limit_backward = self.I_pV
        v_4 = self.limit - self.cursor
        self.__r_ending()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_verb()
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        self.__r_adjective()
        self.cursor = self.limit - v_6
        v_7 = self.limit - self.cursor
        self.__r_noun()
        self.cursor = self.limit - v_7
        self.limit_backward = v_3
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among(u"րորդ", -1, 1),
        Among(u"երորդ", 0, 1),
        Among(u"ալի", -1, 1),
        Among(u"ակի", -1, 1),
        Among(u"որակ", -1, 1),
        Among(u"եղ", -1, 1),
        Among(u"ական", -1, 1),
        Among(u"արան", -1, 1),
        Among(u"են", -1, 1),
        Among(u"եկեն", 8, 1),
        Among(u"երեն", 8, 1),
        Among(u"որէն", -1, 1),
        Among(u"ին", -1, 1),
        Among(u"գին", 12, 1),
        Among(u"ովին", 12, 1),
        Among(u"լայն", -1, 1),
        Among(u"վուն", -1, 1),
        Among(u"պես", -1, 1),
        Among(u"իվ", -1, 1),
        Among(u"ատ", -1, 1),
        Among(u"ավետ", -1, 1),
        Among(u"կոտ", -1, 1),
        Among(u"բար", -1, 1)
    ]

    a_1 = [
        Among(u"ա", -1, 1),
        Among(u"ացա", 0, 1),
        Among(u"եցա", 0, 1),
        Among(u"վե", -1, 1),
        Among(u"ացրի", -1, 1),
        Among(u"ացի", -1, 1),
        Among(u"եցի", -1, 1),
        Among(u"վեցի", 6, 1),
        Among(u"ալ", -1, 1),
        Among(u"ըալ", 8, 1),
        Among(u"անալ", 8, 1),
        Among(u"ենալ", 8, 1),
        Among(u"ացնալ", 8, 1),
        Among(u"ել", -1, 1),
        Among(u"ըել", 13, 1),
        Among(u"նել", 13, 1),
        Among(u"ցնել", 15, 1),
        Among(u"եցնել", 16, 1),
        Among(u"չել", 13, 1),
        Among(u"վել", 13, 1),
        Among(u"ացվել", 19, 1),
        Among(u"եցվել", 19, 1),
        Among(u"տել", 13, 1),
        Among(u"ատել", 22, 1),
        Among(u"ոտել", 22, 1),
        Among(u"կոտել", 24, 1),
        Among(u"ված", -1, 1),
        Among(u"ում", -1, 1),
        Among(u"վում", 27, 1),
        Among(u"ան", -1, 1),
        Among(u"ցան", 29, 1),
        Among(u"ացան", 30, 1),
        Among(u"ացրին", -1, 1),
        Among(u"ացին", -1, 1),
        Among(u"եցին", -1, 1),
        Among(u"վեցին", 34, 1),
        Among(u"ալիս", -1, 1),
        Among(u"ելիս", -1, 1),
        Among(u"ավ", -1, 1),
        Among(u"ացավ", 38, 1),
        Among(u"եցավ", 38, 1),
        Among(u"ալով", -1, 1),
        Among(u"ելով", -1, 1),
        Among(u"ար", -1, 1),
        Among(u"ացար", 43, 1),
        Among(u"եցար", 43, 1),
        Among(u"ացրիր", -1, 1),
        Among(u"ացիր", -1, 1),
        Among(u"եցիր", -1, 1),
        Among(u"վեցիր", 48, 1),
        Among(u"աց", -1, 1),
        Among(u"եց", -1, 1),
        Among(u"ացրեց", 51, 1),
        Among(u"ալուց", -1, 1),
        Among(u"ելուց", -1, 1),
        Among(u"ալու", -1, 1),
        Among(u"ելու", -1, 1),
        Among(u"աք", -1, 1),
        Among(u"ցաք", 57, 1),
        Among(u"ացաք", 58, 1),
        Among(u"ացրիք", -1, 1),
        Among(u"ացիք", -1, 1),
        Among(u"եցիք", -1, 1),
        Among(u"վեցիք", 62, 1),
        Among(u"անք", -1, 1),
        Among(u"ցանք", 64, 1),
        Among(u"ացանք", 65, 1),
        Among(u"ացրինք", -1, 1),
        Among(u"ացինք", -1, 1),
        Among(u"եցինք", -1, 1),
        Among(u"վեցինք", 69, 1)
    ]

    a_2 = [
        Among(u"որդ", -1, 1),
        Among(u"ույթ", -1, 1),
        Among(u"ուհի", -1, 1),
        Among(u"ցի", -1, 1),
        Among(u"իլ", -1, 1),
        Among(u"ակ", -1, 1),
        Among(u"յակ", 5, 1),
        Among(u"անակ", 5, 1),
        Among(u"իկ", -1, 1),
        Among(u"ուկ", -1, 1),
        Among(u"ան", -1, 1),
        Among(u"պան", 10, 1),
        Among(u"ստան", 10, 1),
        Among(u"արան", 10, 1),
        Among(u"եղէն", -1, 1),
        Among(u"յուն", -1, 1),
        Among(u"ություն", 15, 1),
        Among(u"ածո", -1, 1),
        Among(u"իչ", -1, 1),
        Among(u"ուս", -1, 1),
        Among(u"ուստ", -1, 1),
        Among(u"գար", -1, 1),
        Among(u"վոր", -1, 1),
        Among(u"ավոր", 22, 1),
        Among(u"ոց", -1, 1),
        Among(u"անօց", -1, 1),
        Among(u"ու", -1, 1),
        Among(u"ք", -1, 1),
        Among(u"չեք", 27, 1),
        Among(u"իք", 27, 1),
        Among(u"ալիք", 29, 1),
        Among(u"անիք", 29, 1),
        Among(u"վածք", 27, 1),
        Among(u"ույք", 27, 1),
        Among(u"ենք", 27, 1),
        Among(u"ոնք", 27, 1),
        Among(u"ունք", 27, 1),
        Among(u"մունք", 36, 1),
        Among(u"իչք", 27, 1),
        Among(u"արք", 27, 1)
    ]

    a_3 = [
        Among(u"սա", -1, 1),
        Among(u"վա", -1, 1),
        Among(u"ամբ", -1, 1),
        Among(u"դ", -1, 1),
        Among(u"անդ", 3, 1),
        Among(u"ությանդ", 4, 1),
        Among(u"վանդ", 4, 1),
        Among(u"ոջդ", 3, 1),
        Among(u"երդ", 3, 1),
        Among(u"ներդ", 8, 1),
        Among(u"ուդ", 3, 1),
        Among(u"ը", -1, 1),
        Among(u"անը", 11, 1),
        Among(u"ությանը", 12, 1),
        Among(u"վանը", 12, 1),
        Among(u"ոջը", 11, 1),
        Among(u"երը", 11, 1),
        Among(u"ները", 16, 1),
        Among(u"ի", -1, 1),
        Among(u"վի", 18, 1),
        Among(u"երի", 18, 1),
        Among(u"ների", 20, 1),
        Among(u"անում", -1, 1),
        Among(u"երում", -1, 1),
        Among(u"ներում", 23, 1),
        Among(u"ն", -1, 1),
        Among(u"ան", 25, 1),
        Among(u"ության", 26, 1),
        Among(u"վան", 26, 1),
        Among(u"ին", 25, 1),
        Among(u"երին", 29, 1),
        Among(u"ներին", 30, 1),
        Among(u"ությանն", 25, 1),
        Among(u"երն", 25, 1),
        Among(u"ներն", 33, 1),
        Among(u"ուն", 25, 1),
        Among(u"ոջ", -1, 1),
        Among(u"ությանս", -1, 1),
        Among(u"վանս", -1, 1),
        Among(u"ոջս", -1, 1),
        Among(u"ով", -1, 1),
        Among(u"անով", 40, 1),
        Among(u"վով", 40, 1),
        Among(u"երով", 40, 1),
        Among(u"ներով", 43, 1),
        Among(u"եր", -1, 1),
        Among(u"ներ", 45, 1),
        Among(u"ց", -1, 1),
        Among(u"ից", 47, 1),
        Among(u"վանից", 48, 1),
        Among(u"ոջից", 48, 1),
        Among(u"վից", 48, 1),
        Among(u"երից", 48, 1),
        Among(u"ներից", 52, 1),
        Among(u"ցից", 48, 1),
        Among(u"ոց", 47, 1),
        Among(u"ուց", 47, 1)
    ]


class lab0(BaseException): pass



#-*- coding: utf-8 -*-
# Generated from greek.sbl by Snowball 3.0.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class GreekStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from greek.sbl by Snowball 3.0.1 - https://snowballstem.org/
    '''

    g_v = {u"α", u"ε", u"η", u"ι", u"ο", u"υ", u"ω"}

    g_v2 = {u"α", u"ε", u"η", u"ι", u"ο", u"ω"}

    B_test1 = False

    def __r_has_min_length(self):
        return len(self.current) >= 3

    def __r_tolower(self):
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                among_var = self.find_among_b(GreekStemmer.a_0)
                self.bra = self.cursor
                if among_var == 1:
                    if not self.slice_from(u"α"):
                        return False
                elif among_var == 2:
                    if not self.slice_from(u"β"):
                        return False
                elif among_var == 3:
                    if not self.slice_from(u"γ"):
                        return False
                elif among_var == 4:
                    if not self.slice_from(u"δ"):
                        return False
                elif among_var == 5:
                    if not self.slice_from(u"ε"):
                        return False
                elif among_var == 6:
                    if not self.slice_from(u"ζ"):
                        return False
                elif among_var == 7:
                    if not self.slice_from(u"η"):
                        return False
                elif among_var == 8:
                    if not self.slice_from(u"θ"):
                        return False
                elif among_var == 9:
                    if not self.slice_from(u"ι"):
                        return False
                elif among_var == 10:
                    if not self.slice_from(u"κ"):
                        return False
                elif among_var == 11:
                    if not self.slice_from(u"λ"):
                        return False
                elif among_var == 12:
                    if not self.slice_from(u"μ"):
                        return False
                elif among_var == 13:
                    if not self.slice_from(u"ν"):
                        return False
                elif among_var == 14:
                    if not self.slice_from(u"ξ"):
                        return False
                elif among_var == 15:
                    if not self.slice_from(u"ο"):
                        return False
                elif among_var == 16:
                    if not self.slice_from(u"π"):
                        return False
                elif among_var == 17:
                    if not self.slice_from(u"ρ"):
                        return False
                elif among_var == 18:
                    if not self.slice_from(u"σ"):
                        return False
                elif among_var == 19:
                    if not self.slice_from(u"τ"):
                        return False
                elif among_var == 20:
                    if not self.slice_from(u"υ"):
                        return False
                elif among_var == 21:
                    if not self.slice_from(u"φ"):
                        return False
                elif among_var == 22:
                    if not self.slice_from(u"χ"):
                        return False
                elif among_var == 23:
                    if not self.slice_from(u"ψ"):
                        return False
                elif among_var == 24:
                    if not self.slice_from(u"ω"):
                        return False
                else:
                    if self.cursor <= self.limit_backward:
                        raise lab0()
                    self.cursor -= 1
                continue
            except lab0: pass
            self.cursor = self.limit - v_1
            break
        return True

    def __r_step_1(self):
        self.ket = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_1)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.slice_from(u"φα"):
                return False
        elif among_var == 2:
            if not self.slice_from(u"σκα"):
                return False
        elif among_var == 3:
            if not self.slice_from(u"ολο"):
                return False
        elif among_var == 4:
            if not self.slice_from(u"σο"):
                return False
        elif among_var == 5:
            if not self.slice_from(u"τατο"):
                return False
        elif among_var == 6:
            if not self.slice_from(u"κρε"):
                return False
        elif among_var == 7:
            if not self.slice_from(u"περ"):
                return False
        elif among_var == 8:
            if not self.slice_from(u"τερ"):
                return False
        elif among_var == 9:
            if not self.slice_from(u"φω"):
                return False
        elif among_var == 10:
            if not self.slice_from(u"καθεστ"):
                return False
        else:
            if not self.slice_from(u"γεγον"):
                return False
        self.B_test1 = False
        return True

    def __r_step_s1(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_3) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_2)
        if among_var == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if among_var == 1:
            if not self.slice_from(u"ι"):
                return False
        else:
            if not self.slice_from(u"ιζ"):
                return False
        return True

    def __r_step_s2(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_5) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_4) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ων"):
            return False
        return True

    def __r_step_s3(self):
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                if not self.eq_s_b(u"ισα"):
                    raise lab1()
                self.bra = self.cursor
                if self.cursor > self.limit_backward:
                    raise lab1()
                if not self.slice_from(u"ισ"):
                    return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
        except lab0: pass
        if self.find_among_b(GreekStemmer.a_7) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_6)
        if among_var == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if among_var == 1:
            if not self.slice_from(u"ι"):
                return False
        else:
            if not self.slice_from(u"ισ"):
                return False
        return True

    def __r_step_s4(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_9) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_8) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ι"):
            return False
        return True

    def __r_step_s5(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_11) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_10)
        if among_var == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if among_var == 1:
            if not self.slice_from(u"ι"):
                return False
        else:
            if not self.slice_from(u"ιστ"):
                return False
        return True

    def __r_step_s6(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_14) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                among_var = self.find_among_b(GreekStemmer.a_12)
                if among_var == 0:
                    raise lab1()
                if self.cursor > self.limit_backward:
                    raise lab1()
                if among_var == 1:
                    if not self.slice_from(u"ισμ"):
                        return False
                else:
                    if not self.slice_from(u"ι"):
                        return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            among_var = self.find_among_b(GreekStemmer.a_13)
            if among_var == 0:
                return False
            self.bra = self.cursor
            if among_var == 1:
                if not self.slice_from(u"αγνωστ"):
                    return False
            elif among_var == 2:
                if not self.slice_from(u"ατομ"):
                    return False
            elif among_var == 3:
                if not self.slice_from(u"γνωστ"):
                    return False
            elif among_var == 4:
                if not self.slice_from(u"εθν"):
                    return False
            elif among_var == 5:
                if not self.slice_from(u"εκλεκτ"):
                    return False
            elif among_var == 6:
                if not self.slice_from(u"σκεπτ"):
                    return False
            elif among_var == 7:
                if not self.slice_from(u"τοπ"):
                    return False
            elif among_var == 8:
                if not self.slice_from(u"αλεξανδρ"):
                    return False
            elif among_var == 9:
                if not self.slice_from(u"βυζαντ"):
                    return False
            else:
                if not self.slice_from(u"θεατρ"):
                    return False
        except lab0: pass
        return True

    def __r_step_s7(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_16) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_15) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"αρακ"):
            return False
        return True

    def __r_step_s8(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_18) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                among_var = self.find_among_b(GreekStemmer.a_17)
                if among_var == 0:
                    raise lab1()
                if self.cursor > self.limit_backward:
                    raise lab1()
                if among_var == 1:
                    if not self.slice_from(u"ακ"):
                        return False
                else:
                    if not self.slice_from(u"ιτσ"):
                        return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if not self.eq_s_b(u"κορ"):
                return False
            if not self.slice_from(u"ιτσ"):
                return False
        except lab0: pass
        return True

    def __r_step_s9(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_21) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_19) == 0:
                    raise lab1()
                if self.cursor > self.limit_backward:
                    raise lab1()
                if not self.slice_from(u"ιδ"):
                    return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_20) == 0:
                return False
            if not self.slice_from(u"ιδ"):
                return False
        except lab0: pass
        return True

    def __r_step_s10(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_23) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_22) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ισκ"):
            return False
        return True

    def __r_step_2a(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_24) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        v_1 = self.limit - self.cursor
        try:
            if self.find_among_b(GreekStemmer.a_25) == 0:
                raise lab0()
            return False
        except lab0: pass
        self.cursor = self.limit - v_1
        c = self.cursor
        self.insert(self.cursor, self.cursor, u"αδ")
        self.cursor = c
        return True

    def __r_step_2b(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_26) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_27) == 0:
            return False
        if not self.slice_from(u"εδ"):
            return False
        return True

    def __r_step_2c(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_28) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_29) == 0:
            return False
        if not self.slice_from(u"ουδ"):
            return False
        return True

    def __r_step_2d(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_30) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_31) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ε"):
            return False
        return True

    def __r_step_3(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_32) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if not self.in_grouping_b(GreekStemmer.g_v):
            return False
        if not self.slice_from(u"ι"):
            return False
        return True

    def __r_step_4(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_33) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.in_grouping_b(GreekStemmer.g_v):
                    raise lab1()
                if not self.slice_from(u"ικ"):
                    return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
        except lab0: pass
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_34) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ικ"):
            return False
        return True

    def __r_step_5a(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.eq_s_b(u"αγαμε"):
                raise lab0()
            self.bra = self.cursor
            if self.cursor > self.limit_backward:
                raise lab0()
            if not self.slice_from(u"αγαμ"):
                return False
        except lab0: pass
        self.cursor = self.limit - v_1
        v_2 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_35) == 0:
                raise lab1()
            self.bra = self.cursor
            if not self.slice_del():
                return False

            self.B_test1 = False
        except lab1: pass
        self.cursor = self.limit - v_2
        self.ket = self.cursor
        if not self.eq_s_b(u"αμε"):
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_36) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"αμ"):
            return False
        return True

    def __r_step_5b(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_38) == 0:
                raise lab0()
            self.bra = self.cursor
            if not self.slice_del():
                return False

            self.B_test1 = False
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_37) == 0:
                raise lab0()
            if self.cursor > self.limit_backward:
                raise lab0()
            if not self.slice_from(u"αγαν"):
                return False
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if not self.eq_s_b(u"ανε"):
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_2 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.in_grouping_b(GreekStemmer.g_v2):
                    raise lab2()
                if not self.slice_from(u"αν"):
                    return False
                raise lab1()
            except lab2: pass
            self.cursor = self.limit - v_2
            self.ket = self.cursor
        except lab1: pass
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_39) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"αν"):
            return False
        return True

    def __r_step_5c(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_40) == 0:
                raise lab0()
            self.bra = self.cursor
            if not self.slice_del():
                return False

            self.B_test1 = False
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if not self.eq_s_b(u"ετε"):
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_2 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.in_grouping_b(GreekStemmer.g_v2):
                    raise lab2()
                if not self.slice_from(u"ετ"):
                    return False
                raise lab1()
            except lab2: pass
            self.cursor = self.limit - v_2
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_41) == 0:
                    raise lab3()
                if not self.slice_from(u"ετ"):
                    return False
                raise lab1()
            except lab3: pass
            self.cursor = self.limit - v_2
            self.ket = self.cursor
        except lab1: pass
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_42) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ετ"):
            return False
        return True

    def __r_step_5d(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_43) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.eq_s_b(u"αρχ"):
                    raise lab1()
                if self.cursor > self.limit_backward:
                    raise lab1()
                if not self.slice_from(u"οντ"):
                    return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if not self.eq_s_b(u"κρε"):
                return False
            if not self.slice_from(u"ωντ"):
                return False
        except lab0: pass
        return True

    def __r_step_5e(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_44) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if not self.eq_s_b(u"ον"):
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ομαστ"):
            return False
        return True

    def __r_step_5f(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.eq_s_b(u"ιεστε"):
                raise lab0()
            self.bra = self.cursor
            if not self.slice_del():
                return False

            self.B_test1 = False
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_45) == 0:
                raise lab0()
            if self.cursor > self.limit_backward:
                raise lab0()
            if not self.slice_from(u"ιεστ"):
                return False
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if not self.eq_s_b(u"εστε"):
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_46) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ιεστ"):
            return False
        return True

    def __r_step_5g(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_47) == 0:
                raise lab0()
            self.bra = self.cursor
            if not self.slice_del():
                return False

            self.B_test1 = False
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_50) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_2 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_48) == 0:
                    raise lab2()
                if not self.slice_from(u"ηκ"):
                    return False
                raise lab1()
            except lab2: pass
            self.cursor = self.limit - v_2
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_49) == 0:
                return False
            if self.cursor > self.limit_backward:
                return False
            if not self.slice_from(u"ηκ"):
                return False
        except lab1: pass
        return True

    def __r_step_5h(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_53) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_51) == 0:
                    raise lab1()
                if not self.slice_from(u"ουσ"):
                    return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_52) == 0:
                return False
            if self.cursor > self.limit_backward:
                return False
            if not self.slice_from(u"ουσ"):
                return False
        except lab0: pass
        return True

    def __r_step_5i(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_56) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        try:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.eq_s_b(u"κολλ"):
                    raise lab1()
                if not self.slice_from(u"αγ"):
                    return False
                raise lab0()
            except lab1: pass
            self.cursor = self.limit - v_1
            try:
                v_2 = self.limit - self.cursor
                try:
                    self.ket = self.cursor
                    self.bra = self.cursor
                    among_var = self.find_among_b(GreekStemmer.a_54)
                    if among_var == 0:
                        raise lab3()
                    if among_var == 1:
                        if not self.slice_from(u"αγ"):
                            return False
                    raise lab2()
                except lab3: pass
                self.cursor = self.limit - v_2
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_55) == 0:
                    return False
                if self.cursor > self.limit_backward:
                    return False
                if not self.slice_from(u"αγ"):
                    return False
            except lab2: pass
        except lab0: pass
        return True

    def __r_step_5j(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_57) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_58) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ησ"):
            return False
        return True

    def __r_step_5k(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_59) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_60) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ηστ"):
            return False
        return True

    def __r_step_5l(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_61) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_62) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ουν"):
            return False
        return True

    def __r_step_5m(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_63) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_64) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        if not self.slice_from(u"ουμ"):
            return False
        return True

    def __r_step_6(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_65) == 0:
                raise lab0()
            self.bra = self.cursor
            if not self.slice_from(u"μα"):
                return False
        except lab0: pass
        self.cursor = self.limit - v_1
        if not self.B_test1:
            return False
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_66) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        return True

    def __r_step_7(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_67) == 0:
            return False
        self.bra = self.cursor
        if not self.slice_del():
            return False

        return True

    def _stem(self):
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_1 = self.limit - self.cursor
        self.__r_tolower()
        self.cursor = self.limit - v_1
        if not self.__r_has_min_length():
            return False
        self.B_test1 = True
        v_2 = self.limit - self.cursor
        self.__r_step_1()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_step_s1()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_step_s2()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_step_s3()
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        self.__r_step_s4()
        self.cursor = self.limit - v_6
        v_7 = self.limit - self.cursor
        self.__r_step_s5()
        self.cursor = self.limit - v_7
        v_8 = self.limit - self.cursor
        self.__r_step_s6()
        self.cursor = self.limit - v_8
        v_9 = self.limit - self.cursor
        self.__r_step_s7()
        self.cursor = self.limit - v_9
        v_10 = self.limit - self.cursor
        self.__r_step_s8()
        self.cursor = self.limit - v_10
        v_11 = self.limit - self.cursor
        self.__r_step_s9()
        self.cursor = self.limit - v_11
        v_12 = self.limit - self.cursor
        self.__r_step_s10()
        self.cursor = self.limit - v_12
        v_13 = self.limit - self.cursor
        self.__r_step_2a()
        self.cursor = self.limit - v_13
        v_14 = self.limit - self.cursor
        self.__r_step_2b()
        self.cursor = self.limit - v_14
        v_15 = self.limit - self.cursor
        self.__r_step_2c()
        self.cursor = self.limit - v_15
        v_16 = self.limit - self.cursor
        self.__r_step_2d()
        self.cursor = self.limit - v_16
        v_17 = self.limit - self.cursor
        self.__r_step_3()
        self.cursor = self.limit - v_17
        v_18 = self.limit - self.cursor
        self.__r_step_4()
        self.cursor = self.limit - v_18
        v_19 = self.limit - self.cursor
        self.__r_step_5a()
        self.cursor = self.limit - v_19
        v_20 = self.limit - self.cursor
        self.__r_step_5b()
        self.cursor = self.limit - v_20
        v_21 = self.limit - self.cursor
        self.__r_step_5c()
        self.cursor = self.limit - v_21
        v_22 = self.limit - self.cursor
        self.__r_step_5d()
        self.cursor = self.limit - v_22
        v_23 = self.limit - self.cursor
        self.__r_step_5e()
        self.cursor = self.limit - v_23
        v_24 = self.limit - self.cursor
        self.__r_step_5f()
        self.cursor = self.limit - v_24
        v_25 = self.limit - self.cursor
        self.__r_step_5g()
        self.cursor = self.limit - v_25
        v_26 = self.limit - self.cursor
        self.__r_step_5h()
        self.cursor = self.limit - v_26
        v_27 = self.limit - self.cursor
        self.__r_step_5j()
        self.cursor = self.limit - v_27
        v_28 = self.limit - self.cursor
        self.__r_step_5i()
        self.cursor = self.limit - v_28
        v_29 = self.limit - self.cursor
        self.__r_step_5k()
        self.cursor = self.limit - v_29
        v_30 = self.limit - self.cursor
        self.__r_step_5l()
        self.cursor = self.limit - v_30
        v_31 = self.limit - self.cursor
        self.__r_step_5m()
        self.cursor = self.limit - v_31
        v_32 = self.limit - self.cursor
        self.__r_step_6()
        self.cursor = self.limit - v_32
        v_33 = self.limit - self.cursor
        self.__r_step_7()
        self.cursor = self.limit - v_33
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among(u"", -1, 25),
        Among(u"Ά", 0, 1),
        Among(u"Έ", 0, 5),
        Among(u"Ή", 0, 7),
        Among(u"Ί", 0, 9),
        Among(u"Ό", 0, 15),
        Among(u"Ύ", 0, 20),
        Among(u"Ώ", 0, 24),
        Among(u"ΐ", 0, 7),
        Among(u"Α", 0, 1),
        Among(u"Β", 0, 2),
        Among(u"Γ", 0, 3),
        Among(u"Δ", 0, 4),
        Among(u"Ε", 0, 5),
        Among(u"Ζ", 0, 6),
        Among(u"Η", 0, 7),
        Among(u"Θ", 0, 8),
        Among(u"Ι", 0, 9),
        Among(u"Κ", 0, 10),
        Among(u"Λ", 0, 11),
        Among(u"Μ", 0, 12),
        Among(u"Ν", 0, 13),
        Among(u"Ξ", 0, 14),
        Among(u"Ο", 0, 15),
        Among(u"Π", 0, 16),
        Among(u"Ρ", 0, 17),
        Among(u"Σ", 0, 18),
        Among(u"Τ", 0, 19),
        Among(u"Υ", 0, 20),
        Among(u"Φ", 0, 21),
        Among(u"Χ", 0, 22),
        Among(u"Ψ", 0, 23),
        Among(u"Ω", 0, 24),
        Among(u"Ϊ", 0, 9),
        Among(u"Ϋ", 0, 20),
        Among(u"ά", 0, 1),
        Among(u"έ", 0, 5),
        Among(u"ή", 0, 7),
        Among(u"ί", 0, 9),
        Among(u"ΰ", 0, 20),
        Among(u"ς", 0, 18),
        Among(u"ϊ", 0, 7),
        Among(u"ϋ", 0, 20),
        Among(u"ό", 0, 15),
        Among(u"ύ", 0, 20),
        Among(u"ώ", 0, 24)
    ]

    a_1 = [
        Among(u"σκαγια", -1, 2),
        Among(u"φαγια", -1, 1),
        Among(u"ολογια", -1, 3),
        Among(u"σογια", -1, 4),
        Among(u"τατογια", -1, 5),
        Among(u"κρεατα", -1, 6),
        Among(u"περατα", -1, 7),
        Among(u"τερατα", -1, 8),
        Among(u"γεγονοτα", -1, 11),
        Among(u"καθεστωτα", -1, 10),
        Among(u"φωτα", -1, 9),
        Among(u"περατη", -1, 7),
        Among(u"σκαγιων", -1, 2),
        Among(u"φαγιων", -1, 1),
        Among(u"ολογιων", -1, 3),
        Among(u"σογιων", -1, 4),
        Among(u"τατογιων", -1, 5),
        Among(u"κρεατων", -1, 6),
        Among(u"περατων", -1, 7),
        Among(u"τερατων", -1, 8),
        Among(u"γεγονοτων", -1, 11),
        Among(u"καθεστωτων", -1, 10),
        Among(u"φωτων", -1, 9),
        Among(u"κρεασ", -1, 6),
        Among(u"περασ", -1, 7),
        Among(u"τερασ", -1, 8),
        Among(u"γεγονοσ", -1, 11),
        Among(u"κρεατοσ", -1, 6),
        Among(u"περατοσ", -1, 7),
        Among(u"τερατοσ", -1, 8),
        Among(u"γεγονοτοσ", -1, 11),
        Among(u"καθεστωτοσ", -1, 10),
        Among(u"φωτοσ", -1, 9),
        Among(u"καθεστωσ", -1, 10),
        Among(u"φωσ", -1, 9),
        Among(u"σκαγιου", -1, 2),
        Among(u"φαγιου", -1, 1),
        Among(u"ολογιου", -1, 3),
        Among(u"σογιου", -1, 4),
        Among(u"τατογιου", -1, 5)
    ]

    a_2 = [
        Among(u"πα", -1, 1),
        Among(u"ξαναπα", 0, 1),
        Among(u"επα", 0, 1),
        Among(u"περιπα", 0, 1),
        Among(u"αναμπα", 0, 1),
        Among(u"εμπα", 0, 1),
        Among(u"β", -1, 2),
        Among(u"δανε", -1, 1),
        Among(u"βαθυρι", -1, 2),
        Among(u"βαρκ", -1, 2),
        Among(u"μαρκ", -1, 2),
        Among(u"λ", -1, 2),
        Among(u"μ", -1, 2),
        Among(u"κορν", -1, 2),
        Among(u"αθρο", -1, 1),
        Among(u"συναθρο", 14, 1),
        Among(u"π", -1, 2),
        Among(u"ιμπ", 16, 2),
        Among(u"ρ", -1, 2),
        Among(u"μαρ", 18, 2),
        Among(u"αμπαρ", 18, 2),
        Among(u"γκρ", 18, 2),
        Among(u"βολβορ", 18, 2),
        Among(u"γλυκορ", 18, 2),
        Among(u"πιπερορ", 18, 2),
        Among(u"πρ", 18, 2),
        Among(u"μπρ", 25, 2),
        Among(u"αρρ", 18, 2),
        Among(u"γλυκυρ", 18, 2),
        Among(u"πολυρ", 18, 2),
        Among(u"λου", -1, 2)
    ]

    a_3 = [
        Among(u"ιζα", -1, 1),
        Among(u"ιζε", -1, 1),
        Among(u"ιζαμε", -1, 1),
        Among(u"ιζουμε", -1, 1),
        Among(u"ιζανε", -1, 1),
        Among(u"ιζουνε", -1, 1),
        Among(u"ιζατε", -1, 1),
        Among(u"ιζετε", -1, 1),
        Among(u"ιζει", -1, 1),
        Among(u"ιζαν", -1, 1),
        Among(u"ιζουν", -1, 1),
        Among(u"ιζεσ", -1, 1),
        Among(u"ιζεισ", -1, 1),
        Among(u"ιζω", -1, 1)
    ]

    a_4 = [
        Among(u"βι", -1, 1),
        Among(u"λι", -1, 1),
        Among(u"αλ", -1, 1),
        Among(u"εν", -1, 1),
        Among(u"σ", -1, 1),
        Among(u"χ", -1, 1),
        Among(u"υψ", -1, 1),
        Among(u"ζω", -1, 1)
    ]

    a_5 = [
        Among(u"ωθηκα", -1, 1),
        Among(u"ωθηκε", -1, 1),
        Among(u"ωθηκαμε", -1, 1),
        Among(u"ωθηκανε", -1, 1),
        Among(u"ωθηκατε", -1, 1),
        Among(u"ωθηκαν", -1, 1),
        Among(u"ωθηκεσ", -1, 1)
    ]

    a_6 = [
        Among(u"ξαναπα", -1, 1),
        Among(u"επα", -1, 1),
        Among(u"περιπα", -1, 1),
        Among(u"αναμπα", -1, 1),
        Among(u"εμπα", -1, 1),
        Among(u"χαρτοπα", -1, 1),
        Among(u"εξαρχα", -1, 1),
        Among(u"γε", -1, 2),
        Among(u"γκε", -1, 2),
        Among(u"κλε", -1, 1),
        Among(u"εκλε", 9, 1),
        Among(u"απεκλε", 10, 1),
        Among(u"αποκλε", 9, 1),
        Among(u"εσωκλε", 9, 1),
        Among(u"δανε", -1, 1),
        Among(u"πε", -1, 1),
        Among(u"επε", 15, 1),
        Among(u"μετεπε", 16, 1),
        Among(u"εσε", -1, 1),
        Among(u"γκ", -1, 2),
        Among(u"μ", -1, 2),
        Among(u"πουκαμ", 20, 2),
        Among(u"κομ", 20, 2),
        Among(u"αν", -1, 2),
        Among(u"ολο", -1, 2),
        Among(u"αθρο", -1, 1),
        Among(u"συναθρο", 25, 1),
        Among(u"π", -1, 2),
        Among(u"λαρ", -1, 2),
        Among(u"δημοκρατ", -1, 2),
        Among(u"αφ", -1, 2),
        Among(u"γιγαντοαφ", 30, 2)
    ]

    a_7 = [
        Among(u"ισα", -1, 1),
        Among(u"ισαμε", -1, 1),
        Among(u"ισανε", -1, 1),
        Among(u"ισε", -1, 1),
        Among(u"ισατε", -1, 1),
        Among(u"ισαν", -1, 1),
        Among(u"ισεσ", -1, 1)
    ]

    a_8 = [
        Among(u"ξαναπα", -1, 1),
        Among(u"επα", -1, 1),
        Among(u"περιπα", -1, 1),
        Among(u"αναμπα", -1, 1),
        Among(u"εμπα", -1, 1),
        Among(u"χαρτοπα", -1, 1),
        Among(u"εξαρχα", -1, 1),
        Among(u"κλε", -1, 1),
        Among(u"εκλε", 7, 1),
        Among(u"απεκλε", 8, 1),
        Among(u"αποκλε", 7, 1),
        Among(u"εσωκλε", 7, 1),
        Among(u"δανε", -1, 1),
        Among(u"πε", -1, 1),
        Among(u"επε", 13, 1),
        Among(u"μετεπε", 14, 1),
        Among(u"εσε", -1, 1),
        Among(u"αθρο", -1, 1),
        Among(u"συναθρο", 17, 1)
    ]

    a_9 = [
        Among(u"ισουμε", -1, 1),
        Among(u"ισουνε", -1, 1),
        Among(u"ισετε", -1, 1),
        Among(u"ισει", -1, 1),
        Among(u"ισουν", -1, 1),
        Among(u"ισεισ", -1, 1),
        Among(u"ισω", -1, 1)
    ]

    a_10 = [
        Among(u"ατα", -1, 2),
        Among(u"φα", -1, 2),
        Among(u"ηφα", 1, 2),
        Among(u"μεγ", -1, 2),
        Among(u"λυγ", -1, 2),
        Among(u"ηδ", -1, 2),
        Among(u"κλε", -1, 1),
        Among(u"εσωκλε", 6, 1),
        Among(u"πλε", -1, 1),
        Among(u"δανε", -1, 1),
        Among(u"σε", -1, 1),
        Among(u"ασε", 10, 1),
        Among(u"καθ", -1, 2),
        Among(u"εχθ", -1, 2),
        Among(u"κακ", -1, 2),
        Among(u"μακ", -1, 2),
        Among(u"σκ", -1, 2),
        Among(u"φιλ", -1, 2),
        Among(u"κυλ", -1, 2),
        Among(u"μ", -1, 2),
        Among(u"γεμ", 19, 2),
        Among(u"αχν", -1, 2),
        Among(u"συναθρο", -1, 1),
        Among(u"π", -1, 2),
        Among(u"απ", 23, 2),
        Among(u"εμπ", 23, 2),
        Among(u"ευπ", 23, 2),
        Among(u"αρ", -1, 2),
        Among(u"αορ", -1, 2),
        Among(u"γυρ", -1, 2),
        Among(u"χρ", -1, 2),
        Among(u"χωρ", -1, 2),
        Among(u"κτ", -1, 2),
        Among(u"ακτ", 32, 2),
        Among(u"χτ", -1, 2),
        Among(u"αχτ", 34, 2),
        Among(u"ταχ", -1, 2),
        Among(u"σχ", -1, 2),
        Among(u"ασχ", 37, 2),
        Among(u"υψ", -1, 2)
    ]

    a_11 = [
        Among(u"ιστα", -1, 1),
        Among(u"ιστε", -1, 1),
        Among(u"ιστη", -1, 1),
        Among(u"ιστοι", -1, 1),
        Among(u"ιστων", -1, 1),
        Among(u"ιστο", -1, 1),
        Among(u"ιστεσ", -1, 1),
        Among(u"ιστησ", -1, 1),
        Among(u"ιστοσ", -1, 1),
        Among(u"ιστουσ", -1, 1),
        Among(u"ιστου", -1, 1)
    ]

    a_12 = [
        Among(u"εγκλε", -1, 1),
        Among(u"αποκλε", -1, 1),
        Among(u"δανε", -1, 2),
        Among(u"αντιδανε", 2, 2),
        Among(u"σε", -1, 1),
        Among(u"μετασε", 4, 1),
        Among(u"μικροσε", 4, 1)
    ]

    a_13 = [
        Among(u"ατομικ", -1, 2),
        Among(u"εθνικ", -1, 4),
        Among(u"τοπικ", -1, 7),
        Among(u"εκλεκτικ", -1, 5),
        Among(u"σκεπτικ", -1, 6),
        Among(u"γνωστικ", -1, 3),
        Among(u"αγνωστικ", 5, 1),
        Among(u"αλεξανδριν", -1, 8),
        Among(u"θεατριν", -1, 10),
        Among(u"βυζαντιν", -1, 9)
    ]

    a_14 = [
        Among(u"ισμοι", -1, 1),
        Among(u"ισμων", -1, 1),
        Among(u"ισμο", -1, 1),
        Among(u"ισμοσ", -1, 1),
        Among(u"ισμουσ", -1, 1),
        Among(u"ισμου", -1, 1)
    ]

    a_15 = [
        Among(u"σ", -1, 1),
        Among(u"χ", -1, 1)
    ]

    a_16 = [
        Among(u"ουδακια", -1, 1),
        Among(u"αρακια", -1, 1),
        Among(u"ουδακι", -1, 1),
        Among(u"αρακι", -1, 1)
    ]

    a_17 = [
        Among(u"β", -1, 2),
        Among(u"βαμβ", 0, 1),
        Among(u"σλοβ", 0, 1),
        Among(u"τσεχοσλοβ", 2, 1),
        Among(u"καρδ", -1, 2),
        Among(u"ζ", -1, 2),
        Among(u"τζ", 5, 1),
        Among(u"κ", -1, 1),
        Among(u"καπακ", 7, 1),
        Among(u"σοκ", 7, 1),
        Among(u"σκ", 7, 1),
        Among(u"βαλ", -1, 2),
        Among(u"μαλ", -1, 1),
        Among(u"γλ", -1, 2),
        Among(u"τριπολ", -1, 2),
        Among(u"πλ", -1, 1),
        Among(u"λουλ", -1, 1),
        Among(u"φυλ", -1, 1),
        Among(u"καιμ", -1, 1),
        Among(u"κλιμ", -1, 1),
        Among(u"φαρμ", -1, 1),
        Among(u"γιαν", -1, 2),
        Among(u"σπαν", -1, 1),
        Among(u"ηγουμεν", -1, 2),
        Among(u"κον", -1, 1),
        Among(u"μακρυν", -1, 2),
        Among(u"π", -1, 2),
        Among(u"κατραπ", 26, 1),
        Among(u"ρ", -1, 1),
        Among(u"βρ", 28, 1),
        Among(u"λαβρ", 29, 1),
        Among(u"αμβρ", 29, 1),
        Among(u"μερ", 28, 1),
        Among(u"πατερ", 28, 2),
        Among(u"ανθρ", 28, 1),
        Among(u"κορ", 28, 1),
        Among(u"σ", -1, 1),
        Among(u"ναγκασ", 36, 1),
        Among(u"τοσ", 36, 2),
        Among(u"μουστ", -1, 1),
        Among(u"ρυ", -1, 1),
        Among(u"φ", -1, 1),
        Among(u"σφ", 41, 1),
        Among(u"αλισφ", 42, 1),
        Among(u"νυφ", 41, 2),
        Among(u"χ", -1, 1)
    ]

    a_18 = [
        Among(u"ακια", -1, 1),
        Among(u"αρακια", 0, 1),
        Among(u"ιτσα", -1, 1),
        Among(u"ακι", -1, 1),
        Among(u"αρακι", 3, 1),
        Among(u"ιτσων", -1, 1),
        Among(u"ιτσασ", -1, 1),
        Among(u"ιτσεσ", -1, 1)
    ]

    a_19 = [
        Among(u"ψαλ", -1, 1),
        Among(u"αιφν", -1, 1),
        Among(u"ολο", -1, 1),
        Among(u"ιρ", -1, 1)
    ]

    a_20 = [
        Among(u"ε", -1, 1),
        Among(u"παιχν", -1, 1)
    ]

    a_21 = [
        Among(u"ιδια", -1, 1),
        Among(u"ιδιων", -1, 1),
        Among(u"ιδιο", -1, 1)
    ]

    a_22 = [
        Among(u"ιβ", -1, 1),
        Among(u"δ", -1, 1),
        Among(u"φραγκ", -1, 1),
        Among(u"λυκ", -1, 1),
        Among(u"οβελ", -1, 1),
        Among(u"μην", -1, 1),
        Among(u"ρ", -1, 1)
    ]

    a_23 = [
        Among(u"ισκε", -1, 1),
        Among(u"ισκο", -1, 1),
        Among(u"ισκοσ", -1, 1),
        Among(u"ισκου", -1, 1)
    ]

    a_24 = [
        Among(u"αδων", -1, 1),
        Among(u"αδεσ", -1, 1)
    ]

    a_25 = [
        Among(u"γιαγι", -1, -1),
        Among(u"θει", -1, -1),
        Among(u"οκ", -1, -1),
        Among(u"μαμ", -1, -1),
        Among(u"μαν", -1, -1),
        Among(u"μπαμπ", -1, -1),
        Among(u"πεθερ", -1, -1),
        Among(u"πατερ", -1, -1),
        Among(u"κυρ", -1, -1),
        Among(u"νταντ", -1, -1)
    ]

    a_26 = [
        Among(u"εδων", -1, 1),
        Among(u"εδεσ", -1, 1)
    ]

    a_27 = [
        Among(u"μιλ", -1, 1),
        Among(u"δαπ", -1, 1),
        Among(u"γηπ", -1, 1),
        Among(u"ιπ", -1, 1),
        Among(u"εμπ", -1, 1),
        Among(u"οπ", -1, 1),
        Among(u"κρασπ", -1, 1),
        Among(u"υπ", -1, 1)
    ]

    a_28 = [
        Among(u"ουδων", -1, 1),
        Among(u"ουδεσ", -1, 1)
    ]

    a_29 = [
        Among(u"τραγ", -1, 1),
        Among(u"φε", -1, 1),
        Among(u"καλιακ", -1, 1),
        Among(u"αρκ", -1, 1),
        Among(u"σκ", -1, 1),
        Among(u"πεταλ", -1, 1),
        Among(u"βελ", -1, 1),
        Among(u"λουλ", -1, 1),
        Among(u"φλ", -1, 1),
        Among(u"χν", -1, 1),
        Among(u"πλεξ", -1, 1),
        Among(u"σπ", -1, 1),
        Among(u"φρ", -1, 1),
        Among(u"σ", -1, 1),
        Among(u"λιχ", -1, 1)
    ]

    a_30 = [
        Among(u"εων", -1, 1),
        Among(u"εωσ", -1, 1)
    ]

    a_31 = [
        Among(u"δ", -1, 1),
        Among(u"ιδ", 0, 1),
        Among(u"θ", -1, 1),
        Among(u"γαλ", -1, 1),
        Among(u"ελ", -1, 1),
        Among(u"ν", -1, 1),
        Among(u"π", -1, 1),
        Among(u"παρ", -1, 1)
    ]

    a_32 = [
        Among(u"ια", -1, 1),
        Among(u"ιων", -1, 1),
        Among(u"ιου", -1, 1)
    ]

    a_33 = [
        Among(u"ικα", -1, 1),
        Among(u"ικων", -1, 1),
        Among(u"ικο", -1, 1),
        Among(u"ικου", -1, 1)
    ]

    a_34 = [
        Among(u"αδ", -1, 1),
        Among(u"συναδ", 0, 1),
        Among(u"καταδ", 0, 1),
        Among(u"αντιδ", -1, 1),
        Among(u"ενδ", -1, 1),
        Among(u"φυλοδ", -1, 1),
        Among(u"υποδ", -1, 1),
        Among(u"πρωτοδ", -1, 1),
        Among(u"εξωδ", -1, 1),
        Among(u"ηθ", -1, 1),
        Among(u"ανηθ", 9, 1),
        Among(u"ξικ", -1, 1),
        Among(u"αλ", -1, 1),
        Among(u"αμμοχαλ", 12, 1),
        Among(u"συνομηλ", -1, 1),
        Among(u"μπολ", -1, 1),
        Among(u"μουλ", -1, 1),
        Among(u"τσαμ", -1, 1),
        Among(u"βρωμ", -1, 1),
        Among(u"αμαν", -1, 1),
        Among(u"μπαν", -1, 1),
        Among(u"καλλιν", -1, 1),
        Among(u"ποστελν", -1, 1),
        Among(u"φιλον", -1, 1),
        Among(u"καλπ", -1, 1),
        Among(u"γερ", -1, 1),
        Among(u"χασ", -1, 1),
        Among(u"μποσ", -1, 1),
        Among(u"πλιατσ", -1, 1),
        Among(u"πετσ", -1, 1),
        Among(u"πιτσ", -1, 1),
        Among(u"φυσ", -1, 1),
        Among(u"μπαγιατ", -1, 1),
        Among(u"νιτ", -1, 1),
        Among(u"πικαντ", -1, 1),
        Among(u"σερτ", -1, 1)
    ]

    a_35 = [
        Among(u"αγαμε", -1, 1),
        Among(u"ηκαμε", -1, 1),
        Among(u"ηθηκαμε", 1, 1),
        Among(u"ησαμε", -1, 1),
        Among(u"ουσαμε", -1, 1)
    ]

    a_36 = [
        Among(u"βουβ", -1, 1),
        Among(u"ξεθ", -1, 1),
        Among(u"πεθ", -1, 1),
        Among(u"αποθ", -1, 1),
        Among(u"αποκ", -1, 1),
        Among(u"ουλ", -1, 1),
        Among(u"αναπ", -1, 1),
        Among(u"πικρ", -1, 1),
        Among(u"ποτ", -1, 1),
        Among(u"αποστ", -1, 1),
        Among(u"χ", -1, 1),
        Among(u"σιχ", 10, 1)
    ]

    a_37 = [
        Among(u"τρ", -1, 1),
        Among(u"τσ", -1, 1)
    ]

    a_38 = [
        Among(u"αγανε", -1, 1),
        Among(u"ηκανε", -1, 1),
        Among(u"ηθηκανε", 1, 1),
        Among(u"ησανε", -1, 1),
        Among(u"ουσανε", -1, 1),
        Among(u"οντανε", -1, 1),
        Among(u"ιοντανε", 5, 1),
        Among(u"ουντανε", -1, 1),
        Among(u"ιουντανε", 7, 1),
        Among(u"οτανε", -1, 1),
        Among(u"ιοτανε", 9, 1)
    ]

    a_39 = [
        Among(u"ταβ", -1, 1),
        Among(u"νταβ", 0, 1),
        Among(u"ψηλοταβ", 0, 1),
        Among(u"λιβ", -1, 1),
        Among(u"κλιβ", 3, 1),
        Among(u"ξηροκλιβ", 4, 1),
        Among(u"γ", -1, 1),
        Among(u"αγ", 6, 1),
        Among(u"τραγ", 7, 1),
        Among(u"τσαγ", 7, 1),
        Among(u"αθιγγ", 6, 1),
        Among(u"τσιγγ", 6, 1),
        Among(u"ατσιγγ", 11, 1),
        Among(u"στεγ", 6, 1),
        Among(u"απηγ", 6, 1),
        Among(u"σιγ", 6, 1),
        Among(u"ανοργ", 6, 1),
        Among(u"ενοργ", 6, 1),
        Among(u"καλπουζ", -1, 1),
        Among(u"θ", -1, 1),
        Among(u"μωαμεθ", 19, 1),
        Among(u"πιθ", 19, 1),
        Among(u"απιθ", 21, 1),
        Among(u"δεκ", -1, 1),
        Among(u"πελεκ", -1, 1),
        Among(u"ικ", -1, 1),
        Among(u"ανικ", 25, 1),
        Among(u"βουλκ", -1, 1),
        Among(u"βασκ", -1, 1),
        Among(u"βραχυκ", -1, 1),
        Among(u"γαλ", -1, 1),
        Among(u"καταγαλ", 30, 1),
        Among(u"ολογαλ", 30, 1),
        Among(u"βαθυγαλ", 30, 1),
        Among(u"μελ", -1, 1),
        Among(u"καστελ", -1, 1),
        Among(u"πορτολ", -1, 1),
        Among(u"πλ", -1, 1),
        Among(u"διπλ", 37, 1),
        Among(u"λαοπλ", 37, 1),
        Among(u"ψυχοπλ", 37, 1),
        Among(u"ουλ", -1, 1),
        Among(u"μ", -1, 1),
        Among(u"ολιγοδαμ", 42, 1),
        Among(u"μουσουλμ", 42, 1),
        Among(u"δραδουμ", 42, 1),
        Among(u"βραχμ", 42, 1),
        Among(u"ν", -1, 1),
        Among(u"αμερικαν", 47, 1),
        Among(u"π", -1, 1),
        Among(u"αδαπ", 49, 1),
        Among(u"χαμηλοδαπ", 49, 1),
        Among(u"πολυδαπ", 49, 1),
        Among(u"κοπ", 49, 1),
        Among(u"υποκοπ", 53, 1),
        Among(u"τσοπ", 49, 1),
        Among(u"σπ", 49, 1),
        Among(u"ερ", -1, 1),
        Among(u"γερ", 57, 1),
        Among(u"βετερ", 57, 1),
        Among(u"λουθηρ", -1, 1),
        Among(u"κορμορ", -1, 1),
        Among(u"περιτρ", -1, 1),
        Among(u"ουρ", -1, 1),
        Among(u"σ", -1, 1),
        Among(u"βασ", 64, 1),
        Among(u"πολισ", 64, 1),
        Among(u"σαρακατσ", 64, 1),
        Among(u"θυσ", 64, 1),
        Among(u"διατ", -1, 1),
        Among(u"πλατ", -1, 1),
        Among(u"τσαρλατ", -1, 1),
        Among(u"τετ", -1, 1),
        Among(u"πουριτ", -1, 1),
        Among(u"σουλτ", -1, 1),
        Among(u"μαιντ", -1, 1),
        Among(u"ζωντ", -1, 1),
        Among(u"καστ", -1, 1),
        Among(u"φ", -1, 1),
        Among(u"διαφ", 78, 1),
        Among(u"στεφ", 78, 1),
        Among(u"φωτοστεφ", 80, 1),
        Among(u"περηφ", 78, 1),
        Among(u"υπερηφ", 82, 1),
        Among(u"κοιλαρφ", 78, 1),
        Among(u"πενταρφ", 78, 1),
        Among(u"ορφ", 78, 1),
        Among(u"χ", -1, 1),
        Among(u"αμηχ", 87, 1),
        Among(u"βιομηχ", 87, 1),
        Among(u"μεγλοβιομηχ", 89, 1),
        Among(u"καπνοβιομηχ", 89, 1),
        Among(u"μικροβιομηχ", 89, 1),
        Among(u"πολυμηχ", 87, 1),
        Among(u"λιχ", 87, 1)
    ]

    a_40 = [
        Among(u"ησετε", -1, 1)
    ]

    a_41 = [
        Among(u"ενδ", -1, 1),
        Among(u"συνδ", -1, 1),
        Among(u"οδ", -1, 1),
        Among(u"διαθ", -1, 1),
        Among(u"καθ", -1, 1),
        Among(u"ραθ", -1, 1),
        Among(u"ταθ", -1, 1),
        Among(u"τιθ", -1, 1),
        Among(u"εκθ", -1, 1),
        Among(u"ενθ", -1, 1),
        Among(u"συνθ", -1, 1),
        Among(u"ροθ", -1, 1),
        Among(u"υπερθ", -1, 1),
        Among(u"σθ", -1, 1),
        Among(u"ευθ", -1, 1),
        Among(u"αρκ", -1, 1),
        Among(u"ωφελ", -1, 1),
        Among(u"βολ", -1, 1),
        Among(u"αιν", -1, 1),
        Among(u"πον", -1, 1),
        Among(u"ρον", -1, 1),
        Among(u"συν", -1, 1),
        Among(u"βαρ", -1, 1),
        Among(u"βρ", -1, 1),
        Among(u"αιρ", -1, 1),
        Among(u"φορ", -1, 1),
        Among(u"ευρ", -1, 1),
        Among(u"πυρ", -1, 1),
        Among(u"χωρ", -1, 1),
        Among(u"νετ", -1, 1),
        Among(u"σχ", -1, 1)
    ]

    a_42 = [
        Among(u"παγ", -1, 1),
        Among(u"δ", -1, 1),
        Among(u"αδ", 1, 1),
        Among(u"θ", -1, 1),
        Among(u"αθ", 3, 1),
        Among(u"τοκ", -1, 1),
        Among(u"σκ", -1, 1),
        Among(u"παρακαλ", -1, 1),
        Among(u"σκελ", -1, 1),
        Among(u"απλ", -1, 1),
        Among(u"εμ", -1, 1),
        Among(u"αν", -1, 1),
        Among(u"βεν", -1, 1),
        Among(u"βαρον", -1, 1),
        Among(u"κοπ", -1, 1),
        Among(u"σερπ", -1, 1),
        Among(u"αβαρ", -1, 1),
        Among(u"εναρ", -1, 1),
        Among(u"αβρ", -1, 1),
        Among(u"μπορ", -1, 1),
        Among(u"θαρρ", -1, 1),
        Among(u"ντρ", -1, 1),
        Among(u"υ", -1, 1),
        Among(u"νιφ", -1, 1),
        Among(u"συρφ", -1, 1)
    ]

    a_43 = [
        Among(u"οντασ", -1, 1),
        Among(u"ωντασ", -1, 1)
    ]

    a_44 = [
        Among(u"ομαστε", -1, 1),
        Among(u"ιομαστε", 0, 1)
    ]

    a_45 = [
        Among(u"π", -1, 1),
        Among(u"απ", 0, 1),
        Among(u"ακαταπ", 1, 1),
        Among(u"συμπ", 0, 1),
        Among(u"ασυμπ", 3, 1),
        Among(u"αμεταμφ", -1, 1)
    ]

    a_46 = [
        Among(u"ζ", -1, 1),
        Among(u"αλ", -1, 1),
        Among(u"παρακαλ", 1, 1),
        Among(u"εκτελ", -1, 1),
        Among(u"μ", -1, 1),
        Among(u"ξ", -1, 1),
        Among(u"προ", -1, 1),
        Among(u"αρ", -1, 1),
        Among(u"νισ", -1, 1)
    ]

    a_47 = [
        Among(u"ηθηκα", -1, 1),
        Among(u"ηθηκε", -1, 1),
        Among(u"ηθηκεσ", -1, 1)
    ]

    a_48 = [
        Among(u"πιθ", -1, 1),
        Among(u"οθ", -1, 1),
        Among(u"ναρθ", -1, 1),
        Among(u"σκουλ", -1, 1),
        Among(u"σκωλ", -1, 1),
        Among(u"σφ", -1, 1)
    ]

    a_49 = [
        Among(u"θ", -1, 1),
        Among(u"διαθ", 0, 1),
        Among(u"παρακαταθ", 0, 1),
        Among(u"συνθ", 0, 1),
        Among(u"προσθ", 0, 1)
    ]

    a_50 = [
        Among(u"ηκα", -1, 1),
        Among(u"ηκε", -1, 1),
        Among(u"ηκεσ", -1, 1)
    ]

    a_51 = [
        Among(u"φαγ", -1, 1),
        Among(u"ληγ", -1, 1),
        Among(u"φρυδ", -1, 1),
        Among(u"μαντιλ", -1, 1),
        Among(u"μαλλ", -1, 1),
        Among(u"ομ", -1, 1),
        Among(u"βλεπ", -1, 1),
        Among(u"ποδαρ", -1, 1),
        Among(u"κυματ", -1, 1),
        Among(u"πρωτ", -1, 1),
        Among(u"λαχ", -1, 1),
        Among(u"πανταχ", -1, 1)
    ]

    a_52 = [
        Among(u"τσα", -1, 1),
        Among(u"χαδ", -1, 1),
        Among(u"μεδ", -1, 1),
        Among(u"λαμπιδ", -1, 1),
        Among(u"δε", -1, 1),
        Among(u"πλε", -1, 1),
        Among(u"μεσαζ", -1, 1),
        Among(u"δεσποζ", -1, 1),
        Among(u"αιθ", -1, 1),
        Among(u"φαρμακ", -1, 1),
        Among(u"αγκ", -1, 1),
        Among(u"ανηκ", -1, 1),
        Among(u"λ", -1, 1),
        Among(u"μ", -1, 1),
        Among(u"αμ", 13, 1),
        Among(u"βρομ", 13, 1),
        Among(u"υποτειν", -1, 1),
        Among(u"εκλιπ", -1, 1),
        Among(u"ρ", -1, 1),
        Among(u"ενδιαφερ", 18, 1),
        Among(u"αναρρ", 18, 1),
        Among(u"πατ", -1, 1),
        Among(u"καθαρευ", -1, 1),
        Among(u"δευτερευ", -1, 1),
        Among(u"λεχ", -1, 1)
    ]

    a_53 = [
        Among(u"ουσα", -1, 1),
        Among(u"ουσε", -1, 1),
        Among(u"ουσεσ", -1, 1)
    ]

    a_54 = [
        Among(u"πελ", -1, 1),
        Among(u"λλ", -1, 1),
        Among(u"σμην", -1, 1),
        Among(u"ρπ", -1, 1),
        Among(u"πρ", -1, 1),
        Among(u"φρ", -1, 1),
        Among(u"χορτ", -1, 1),
        Among(u"οφ", -1, 1),
        Among(u"ψοφ", 7, -1),
        Among(u"σφ", -1, 1),
        Among(u"λοχ", -1, 1),
        Among(u"ναυλοχ", 10, -1)
    ]

    a_55 = [
        Among(u"αμαλλι", -1, 1),
        Among(u"λ", -1, 1),
        Among(u"αμαλ", 1, 1),
        Among(u"μ", -1, 1),
        Among(u"ουλαμ", 3, 1),
        Among(u"εν", -1, 1),
        Among(u"δερβεν", 5, 1),
        Among(u"π", -1, 1),
        Among(u"αειπ", 7, 1),
        Among(u"αρτιπ", 7, 1),
        Among(u"συμπ", 7, 1),
        Among(u"νεοπ", 7, 1),
        Among(u"κροκαλοπ", 7, 1),
        Among(u"ολοπ", 7, 1),
        Among(u"προσωποπ", 7, 1),
        Among(u"σιδηροπ", 7, 1),
        Among(u"δροσοπ", 7, 1),
        Among(u"ασπ", 7, 1),
        Among(u"ανυπ", 7, 1),
        Among(u"ρ", -1, 1),
        Among(u"ασπαρ", 19, 1),
        Among(u"χαρ", 19, 1),
        Among(u"αχαρ", 21, 1),
        Among(u"απερ", 19, 1),
        Among(u"τρ", 19, 1),
        Among(u"ουρ", 19, 1),
        Among(u"τ", -1, 1),
        Among(u"διατ", 26, 1),
        Among(u"επιτ", 26, 1),
        Among(u"συντ", 26, 1),
        Among(u"ομοτ", 26, 1),
        Among(u"νομοτ", 30, 1),
        Among(u"αποτ", 26, 1),
        Among(u"υποτ", 26, 1),
        Among(u"αβαστ", 26, 1),
        Among(u"αιμοστ", 26, 1),
        Among(u"προστ", 26, 1),
        Among(u"ανυστ", 26, 1),
        Among(u"ναυ", -1, 1),
        Among(u"αφ", -1, 1),
        Among(u"ξεφ", -1, 1),
        Among(u"αδηφ", -1, 1),
        Among(u"παμφ", -1, 1),
        Among(u"πολυφ", -1, 1)
    ]

    a_56 = [
        Among(u"αγα", -1, 1),
        Among(u"αγε", -1, 1),
        Among(u"αγεσ", -1, 1)
    ]

    a_57 = [
        Among(u"ησα", -1, 1),
        Among(u"ησε", -1, 1),
        Among(u"ησου", -1, 1)
    ]

    a_58 = [
        Among(u"ν", -1, 1),
        Among(u"δωδεκαν", 0, 1),
        Among(u"επταν", 0, 1),
        Among(u"μεγαλον", 0, 1),
        Among(u"ερημον", 0, 1),
        Among(u"χερσον", 0, 1)
    ]

    a_59 = [
        Among(u"ηστε", -1, 1)
    ]

    a_60 = [
        Among(u"σβ", -1, 1),
        Among(u"ασβ", 0, 1),
        Among(u"απλ", -1, 1),
        Among(u"αειμν", -1, 1),
        Among(u"χρ", -1, 1),
        Among(u"αχρ", 4, 1),
        Among(u"κοινοχρ", 4, 1),
        Among(u"δυσχρ", 4, 1),
        Among(u"ευχρ", 4, 1),
        Among(u"παλιμψ", -1, 1)
    ]

    a_61 = [
        Among(u"ουνε", -1, 1),
        Among(u"ηθουνε", 0, 1),
        Among(u"ησουνε", 0, 1)
    ]

    a_62 = [
        Among(u"σπι", -1, 1),
        Among(u"ν", -1, 1),
        Among(u"εξων", 1, 1),
        Among(u"ρ", -1, 1),
        Among(u"στραβομουτσ", -1, 1),
        Among(u"κακομουτσ", -1, 1)
    ]

    a_63 = [
        Among(u"ουμε", -1, 1),
        Among(u"ηθουμε", 0, 1),
        Among(u"ησουμε", 0, 1)
    ]

    a_64 = [
        Among(u"αζ", -1, 1),
        Among(u"ωριοπλ", -1, 1),
        Among(u"ασουσ", -1, 1),
        Among(u"παρασουσ", 2, 1),
        Among(u"αλλοσουσ", -1, 1),
        Among(u"φ", -1, 1),
        Among(u"χ", -1, 1)
    ]

    a_65 = [
        Among(u"ματα", -1, 1),
        Among(u"ματων", -1, 1),
        Among(u"ματοσ", -1, 1)
    ]

    a_66 = [
        Among(u"α", -1, 1),
        Among(u"ιουμα", 0, 1),
        Among(u"ομουνα", 0, 1),
        Among(u"ιομουνα", 2, 1),
        Among(u"οσουνα", 0, 1),
        Among(u"ιοσουνα", 4, 1),
        Among(u"ε", -1, 1),
        Among(u"αγατε", 6, 1),
        Among(u"ηκατε", 6, 1),
        Among(u"ηθηκατε", 8, 1),
        Among(u"ησατε", 6, 1),
        Among(u"ουσατε", 6, 1),
        Among(u"ειτε", 6, 1),
        Among(u"ηθειτε", 12, 1),
        Among(u"ιεμαστε", 6, 1),
        Among(u"ουμαστε", 6, 1),
        Among(u"ιουμαστε", 15, 1),
        Among(u"ιεσαστε", 6, 1),
        Among(u"οσαστε", 6, 1),
        Among(u"ιοσαστε", 18, 1),
        Among(u"η", -1, 1),
        Among(u"ι", -1, 1),
        Among(u"αμαι", 21, 1),
        Among(u"ιεμαι", 21, 1),
        Among(u"ομαι", 21, 1),
        Among(u"ουμαι", 21, 1),
        Among(u"ασαι", 21, 1),
        Among(u"εσαι", 21, 1),
        Among(u"ιεσαι", 27, 1),
        Among(u"αται", 21, 1),
        Among(u"εται", 21, 1),
        Among(u"ιεται", 30, 1),
        Among(u"ονται", 21, 1),
        Among(u"ουνται", 21, 1),
        Among(u"ιουνται", 33, 1),
        Among(u"ει", 21, 1),
        Among(u"αει", 35, 1),
        Among(u"ηθει", 35, 1),
        Among(u"ησει", 35, 1),
        Among(u"οι", 21, 1),
        Among(u"αν", -1, 1),
        Among(u"αγαν", 40, 1),
        Among(u"ηκαν", 40, 1),
        Among(u"ηθηκαν", 42, 1),
        Among(u"ησαν", 40, 1),
        Among(u"ουσαν", 40, 1),
        Among(u"οντουσαν", 45, 1),
        Among(u"ιοντουσαν", 46, 1),
        Among(u"ονταν", 40, 1),
        Among(u"ιονταν", 48, 1),
        Among(u"ουνταν", 40, 1),
        Among(u"ιουνταν", 50, 1),
        Among(u"οταν", 40, 1),
        Among(u"ιοταν", 52, 1),
        Among(u"ομασταν", 40, 1),
        Among(u"ιομασταν", 54, 1),
        Among(u"οσασταν", 40, 1),
        Among(u"ιοσασταν", 56, 1),
        Among(u"ουν", -1, 1),
        Among(u"ηθουν", 58, 1),
        Among(u"ομουν", 58, 1),
        Among(u"ιομουν", 60, 1),
        Among(u"ησουν", 58, 1),
        Among(u"οσουν", 58, 1),
        Among(u"ιοσουν", 63, 1),
        Among(u"ων", -1, 1),
        Among(u"ηδων", 65, 1),
        Among(u"ο", -1, 1),
        Among(u"ασ", -1, 1),
        Among(u"εσ", -1, 1),
        Among(u"ηδεσ", 69, 1),
        Among(u"ησεσ", 69, 1),
        Among(u"ησ", -1, 1),
        Among(u"εισ", -1, 1),
        Among(u"ηθεισ", 73, 1),
        Among(u"οσ", -1, 1),
        Among(u"υσ", -1, 1),
        Among(u"ουσ", 76, 1),
        Among(u"υ", -1, 1),
        Among(u"ου", 78, 1),
        Among(u"ω", -1, 1),
        Among(u"αω", 80, 1),
        Among(u"ηθω", 80, 1),
        Among(u"ησω", 80, 1)
    ]

    a_67 = [
        Among(u"οτερ", -1, 1),
        Among(u"εστερ", -1, 1),
        Among(u"υτερ", -1, 1),
        Among(u"ωτερ", -1, 1),
        Among(u"οτατ", -1, 1),
        Among(u"εστατ", -1, 1),
        Among(u"υτατ", -1, 1),
        Among(u"ωτατ", -1, 1)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass



#-*- coding: utf-8 -*-
# Generated from basque.sbl by Snowball 3.0.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class BasqueStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from basque.sbl by Snowball 3.0.1 - https://snowballstem.org/
    '''

    g_v = {u"a", u"e", u"i", u"o", u"u"}

    I_p2 = 0
    I_p1 = 0
    I_pV = 0

    def __r_mark_regions(self):
        self.I_pV = self.limit
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        v_1 = self.cursor
        try:
            try:
                v_2 = self.cursor
                try:
                    if not self.in_grouping(BasqueStemmer.g_v):
                        raise lab2()
                    try:
                        v_3 = self.cursor
                        try:
                            if not self.out_grouping(BasqueStemmer.g_v):
                                raise lab4()
                            if not self.go_out_grouping(BasqueStemmer.g_v):
                                raise lab4()
                            self.cursor += 1
                            raise lab3()
                        except lab4: pass
                        self.cursor = v_3
                        if not self.in_grouping(BasqueStemmer.g_v):
                            raise lab2()
                        if not self.go_in_grouping(BasqueStemmer.g_v):
                            raise lab2()
                        self.cursor += 1
                    except lab3: pass
                    raise lab1()
                except lab2: pass
                self.cursor = v_2
                if not self.out_grouping(BasqueStemmer.g_v):
                    raise lab0()
                try:
                    v_4 = self.cursor
                    try:
                        if not self.out_grouping(BasqueStemmer.g_v):
                            raise lab6()
                        if not self.go_out_grouping(BasqueStemmer.g_v):
                            raise lab6()
                        self.cursor += 1
                        raise lab5()
                    except lab6: pass
                    self.cursor = v_4
                    if not self.in_grouping(BasqueStemmer.g_v):
                        raise lab0()
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
                except lab5: pass
            except lab1: pass
            self.I_pV = self.cursor
        except lab0: pass
        self.cursor = v_1
        v_5 = self.cursor
        try:
            if not self.go_out_grouping(BasqueStemmer.g_v):
                raise lab7()
            self.cursor += 1
            if not self.go_in_grouping(BasqueStemmer.g_v):
                raise lab7()
            self.cursor += 1
            self.I_p1 = self.cursor
            if not self.go_out_grouping(BasqueStemmer.g_v):
                raise lab7()
            self.cursor += 1
            if not self.go_in_grouping(BasqueStemmer.g_v):
                raise lab7()
            self.cursor += 1
            self.I_p2 = self.cursor
        except lab7: pass
        self.cursor = v_5
        return True

    def __r_RV(self):
        return self.I_pV <= self.cursor

    def __r_R2(self):
        return self.I_p2 <= self.cursor

    def __r_R1(self):
        return self.I_p1 <= self.cursor

    def __r_aditzak(self):
        self.ket = self.cursor
        among_var = self.find_among_b(BasqueStemmer.a_0)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.__r_RV():
                return False
            if not self.slice_del():
                return False

        elif among_var == 2:
            if not self.__r_R2():
                return False
            if not self.slice_del():
                return False

        return True

    def __r_izenak(self):
        self.ket = self.cursor
        among_var = self.find_among_b(BasqueStemmer.a_1)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.__r_RV():
                return False
            if not self.slice_del():
                return False

        elif among_var == 2:
            if not self.__r_R2():
                return False
            if not self.slice_del():
                return False

        elif among_var == 3:
            if not self.slice_from(u"jok"):
                return False
        elif among_var == 4:
            if not self.__r_R1():
                return False
            if not self.slice_del():
                return False

        elif among_var == 5:
            if not self.slice_from(u"tra"):
                return False
        elif among_var == 6:
            if not self.slice_from(u"minutu"):
                return False
        return True

    def __r_adjetiboak(self):
        self.ket = self.cursor
        among_var = self.find_among_b(BasqueStemmer.a_2)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.__r_RV():
                return False
            if not self.slice_del():
                return False

        else:
            if not self.slice_from(u"z"):
                return False
        return True

    def _stem(self):
        self.__r_mark_regions()
        self.limit_backward = self.cursor
        self.cursor = self.limit
        while True:
            v_2 = self.limit - self.cursor
            try:
                if not self.__r_aditzak():
                    raise lab0()
                continue
            except lab0: pass
            self.cursor = self.limit - v_2
            break
        while True:
            v_3 = self.limit - self.cursor
            try:
                if not self.__r_izenak():
                    raise lab1()
                continue
            except lab1: pass
            self.cursor = self.limit - v_3
            break
        v_4 = self.limit - self.cursor
        self.__r_adjetiboak()
        self.cursor = self.limit - v_4
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among(u"idea", -1, 1),
        Among(u"bidea", 0, 1),
        Among(u"kidea", 0, 1),
        Among(u"pidea", 0, 1),
        Among(u"kundea", -1, 1),
        Among(u"galea", -1, 1),
        Among(u"tailea", -1, 1),
        Among(u"tzailea", -1, 1),
        Among(u"gunea", -1, 1),
        Among(u"kunea", -1, 1),
        Among(u"tzaga", -1, 1),
        Among(u"gaia", -1, 1),
        Among(u"aldia", -1, 1),
        Among(u"taldia", 12, 1),
        Among(u"karia", -1, 1),
        Among(u"garria", -1, 2),
        Among(u"karria", -1, 1),
        Among(u"ka", -1, 1),
        Among(u"tzaka", 17, 1),
        Among(u"la", -1, 1),
        Among(u"mena", -1, 1),
        Among(u"pena", -1, 1),
        Among(u"kina", -1, 1),
        Among(u"ezina", -1, 1),
        Among(u"tezina", 23, 1),
        Among(u"kuna", -1, 1),
        Among(u"tuna", -1, 1),
        Among(u"kizuna", -1, 1),
        Among(u"era", -1, 1),
        Among(u"bera", 28, 1),
        Among(u"arabera", 29, -1),
        Among(u"kera", 28, 1),
        Among(u"pera", 28, 1),
        Among(u"orra", -1, 1),
        Among(u"korra", 33, 1),
        Among(u"dura", -1, 1),
        Among(u"gura", -1, 1),
        Among(u"kura", -1, 1),
        Among(u"tura", -1, 1),
        Among(u"eta", -1, 1),
        Among(u"keta", 39, 1),
        Among(u"gailua", -1, 1),
        Among(u"eza", -1, 1),
        Among(u"erreza", 42, 1),
        Among(u"tza", -1, 2),
        Among(u"gaitza", 44, 1),
        Among(u"kaitza", 44, 1),
        Among(u"kuntza", 44, 1),
        Among(u"ide", -1, 1),
        Among(u"bide", 48, 1),
        Among(u"kide", 48, 1),
        Among(u"pide", 48, 1),
        Among(u"kunde", -1, 1),
        Among(u"tzake", -1, 1),
        Among(u"tzeke", -1, 1),
        Among(u"le", -1, 1),
        Among(u"gale", 55, 1),
        Among(u"taile", 55, 1),
        Among(u"tzaile", 55, 1),
        Among(u"gune", -1, 1),
        Among(u"kune", -1, 1),
        Among(u"tze", -1, 1),
        Among(u"atze", 61, 1),
        Among(u"gai", -1, 1),
        Among(u"aldi", -1, 1),
        Among(u"taldi", 64, 1),
        Among(u"ki", -1, 1),
        Among(u"ari", -1, 1),
        Among(u"kari", 67, 1),
        Among(u"lari", 67, 1),
        Among(u"tari", 67, 1),
        Among(u"etari", 70, 1),
        Among(u"garri", -1, 2),
        Among(u"karri", -1, 1),
        Among(u"arazi", -1, 1),
        Among(u"tarazi", 74, 1),
        Among(u"an", -1, 1),
        Among(u"ean", 76, 1),
        Among(u"rean", 77, 1),
        Among(u"kan", 76, 1),
        Among(u"etan", 76, 1),
        Among(u"atseden", -1, -1),
        Among(u"men", -1, 1),
        Among(u"pen", -1, 1),
        Among(u"kin", -1, 1),
        Among(u"rekin", 84, 1),
        Among(u"ezin", -1, 1),
        Among(u"tezin", 86, 1),
        Among(u"tun", -1, 1),
        Among(u"kizun", -1, 1),
        Among(u"go", -1, 1),
        Among(u"ago", 90, 1),
        Among(u"tio", -1, 1),
        Among(u"dako", -1, 1),
        Among(u"or", -1, 1),
        Among(u"kor", 94, 1),
        Among(u"tzat", -1, 1),
        Among(u"du", -1, 1),
        Among(u"gailu", -1, 1),
        Among(u"tu", -1, 1),
        Among(u"atu", 99, 1),
        Among(u"aldatu", 100, 1),
        Among(u"tatu", 100, 1),
        Among(u"baditu", 99, -1),
        Among(u"ez", -1, 1),
        Among(u"errez", 104, 1),
        Among(u"tzez", 104, 1),
        Among(u"gaitz", -1, 1),
        Among(u"kaitz", -1, 1)
    ]

    a_1 = [
        Among(u"ada", -1, 1),
        Among(u"kada", 0, 1),
        Among(u"anda", -1, 1),
        Among(u"denda", -1, 1),
        Among(u"gabea", -1, 1),
        Among(u"kabea", -1, 1),
        Among(u"aldea", -1, 1),
        Among(u"kaldea", 6, 1),
        Among(u"taldea", 6, 1),
        Among(u"ordea", -1, 1),
        Among(u"zalea", -1, 1),
        Among(u"tzalea", 10, 1),
        Among(u"gilea", -1, 1),
        Among(u"emea", -1, 1),
        Among(u"kumea", -1, 1),
        Among(u"nea", -1, 1),
        Among(u"enea", 15, 1),
        Among(u"zionea", 15, 1),
        Among(u"unea", 15, 1),
        Among(u"gunea", 18, 1),
        Among(u"pea", -1, 1),
        Among(u"aurrea", -1, 1),
        Among(u"tea", -1, 1),
        Among(u"kotea", 22, 1),
        Among(u"artea", 22, 1),
        Among(u"ostea", 22, 1),
        Among(u"etxea", -1, 1),
        Among(u"ga", -1, 1),
        Among(u"anga", 27, 1),
        Among(u"gaia", -1, 1),
        Among(u"aldia", -1, 1),
        Among(u"taldia", 30, 1),
        Among(u"handia", -1, 1),
        Among(u"mendia", -1, 1),
        Among(u"geia", -1, 1),
        Among(u"egia", -1, 1),
        Among(u"degia", 35, 1),
        Among(u"tegia", 35, 1),
        Among(u"nahia", -1, 1),
        Among(u"ohia", -1, 1),
        Among(u"kia", -1, 1),
        Among(u"tokia", 40, 1),
        Among(u"oia", -1, 1),
        Among(u"koia", 42, 1),
        Among(u"aria", -1, 1),
        Among(u"karia", 44, 1),
        Among(u"laria", 44, 1),
        Among(u"taria", 44, 1),
        Among(u"eria", -1, 1),
        Among(u"keria", 48, 1),
        Among(u"teria", 48, 1),
        Among(u"garria", -1, 2),
        Among(u"larria", -1, 1),
        Among(u"kirria", -1, 1),
        Among(u"duria", -1, 1),
        Among(u"asia", -1, 1),
        Among(u"tia", -1, 1),
        Among(u"ezia", -1, 1),
        Among(u"bizia", -1, 1),
        Among(u"ontzia", -1, 1),
        Among(u"ka", -1, 1),
        Among(u"joka", 60, 3),
        Among(u"aurka", 60, -1),
        Among(u"ska", 60, 1),
        Among(u"xka", 60, 1),
        Among(u"zka", 60, 1),
        Among(u"gibela", -1, 1),
        Among(u"gela", -1, 1),
        Among(u"kaila", -1, 1),
        Among(u"skila", -1, 1),
        Among(u"tila", -1, 1),
        Among(u"ola", -1, 1),
        Among(u"na", -1, 1),
        Among(u"kana", 72, 1),
        Among(u"ena", 72, 1),
        Among(u"garrena", 74, 1),
        Among(u"gerrena", 74, 1),
        Among(u"urrena", 74, 1),
        Among(u"zaina", 72, 1),
        Among(u"tzaina", 78, 1),
        Among(u"kina", 72, 1),
        Among(u"mina", 72, 1),
        Among(u"garna", 72, 1),
        Among(u"una", 72, 1),
        Among(u"duna", 83, 1),
        Among(u"asuna", 83, 1),
        Among(u"tasuna", 85, 1),
        Among(u"ondoa", -1, 1),
        Among(u"kondoa", 87, 1),
        Among(u"ngoa", -1, 1),
        Among(u"zioa", -1, 1),
        Among(u"koa", -1, 1),
        Among(u"takoa", 91, 1),
        Among(u"zkoa", 91, 1),
        Among(u"noa", -1, 1),
        Among(u"zinoa", 94, 1),
        Among(u"aroa", -1, 1),
        Among(u"taroa", 96, 1),
        Among(u"zaroa", 96, 1),
        Among(u"eroa", -1, 1),
        Among(u"oroa", -1, 1),
        Among(u"osoa", -1, 1),
        Among(u"toa", -1, 1),
        Among(u"ttoa", 102, 1),
        Among(u"ztoa", 102, 1),
        Among(u"txoa", -1, 1),
        Among(u"tzoa", -1, 1),
        Among(u"ñoa", -1, 1),
        Among(u"ra", -1, 1),
        Among(u"ara", 108, 1),
        Among(u"dara", 109, 1),
        Among(u"liara", 109, 1),
        Among(u"tiara", 109, 1),
        Among(u"tara", 109, 1),
        Among(u"etara", 113, 1),
        Among(u"tzara", 109, 1),
        Among(u"bera", 108, 1),
        Among(u"kera", 108, 1),
        Among(u"pera", 108, 1),
        Among(u"ora", 108, 2),
        Among(u"tzarra", 108, 1),
        Among(u"korra", 108, 1),
        Among(u"tra", 108, 1),
        Among(u"sa", -1, 1),
        Among(u"osa", 123, 1),
        Among(u"ta", -1, 1),
        Among(u"eta", 125, 1),
        Among(u"keta", 126, 1),
        Among(u"sta", 125, 1),
        Among(u"dua", -1, 1),
        Among(u"mendua", 129, 1),
        Among(u"ordua", 129, 1),
        Among(u"lekua", -1, 1),
        Among(u"burua", -1, 1),
        Among(u"durua", -1, 1),
        Among(u"tsua", -1, 1),
        Among(u"tua", -1, 1),
        Among(u"mentua", 136, 1),
        Among(u"estua", 136, 1),
        Among(u"txua", -1, 1),
        Among(u"zua", -1, 1),
        Among(u"tzua", 140, 1),
        Among(u"za", -1, 1),
        Among(u"eza", 142, 1),
        Among(u"eroza", 142, 1),
        Among(u"tza", 142, 2),
        Among(u"koitza", 145, 1),
        Among(u"antza", 145, 1),
        Among(u"gintza", 145, 1),
        Among(u"kintza", 145, 1),
        Among(u"kuntza", 145, 1),
        Among(u"gabe", -1, 1),
        Among(u"kabe", -1, 1),
        Among(u"kide", -1, 1),
        Among(u"alde", -1, 1),
        Among(u"kalde", 154, 1),
        Among(u"talde", 154, 1),
        Among(u"orde", -1, 1),
        Among(u"ge", -1, 1),
        Among(u"zale", -1, 1),
        Among(u"tzale", 159, 1),
        Among(u"gile", -1, 1),
        Among(u"eme", -1, 1),
        Among(u"kume", -1, 1),
        Among(u"ne", -1, 1),
        Among(u"zione", 164, 1),
        Among(u"une", 164, 1),
        Among(u"gune", 166, 1),
        Among(u"pe", -1, 1),
        Among(u"aurre", -1, 1),
        Among(u"te", -1, 1),
        Among(u"kote", 170, 1),
        Among(u"arte", 170, 1),
        Among(u"oste", 170, 1),
        Among(u"etxe", -1, 1),
        Among(u"gai", -1, 1),
        Among(u"di", -1, 1),
        Among(u"aldi", 176, 1),
        Among(u"taldi", 177, 1),
        Among(u"geldi", 176, -1),
        Among(u"handi", 176, 1),
        Among(u"mendi", 176, 1),
        Among(u"gei", -1, 1),
        Among(u"egi", -1, 1),
        Among(u"degi", 183, 1),
        Among(u"tegi", 183, 1),
        Among(u"nahi", -1, 1),
        Among(u"ohi", -1, 1),
        Among(u"ki", -1, 1),
        Among(u"toki", 188, 1),
        Among(u"oi", -1, 1),
        Among(u"goi", 190, 1),
        Among(u"koi", 190, 1),
        Among(u"ari", -1, 1),
        Among(u"kari", 193, 1),
        Among(u"lari", 193, 1),
        Among(u"tari", 193, 1),
        Among(u"garri", -1, 2),
        Among(u"larri", -1, 1),
        Among(u"kirri", -1, 1),
        Among(u"duri", -1, 1),
        Among(u"asi", -1, 1),
        Among(u"ti", -1, 1),
        Among(u"ontzi", -1, 1),
        Among(u"ñi", -1, 1),
        Among(u"ak", -1, 1),
        Among(u"ek", -1, 1),
        Among(u"tarik", -1, 1),
        Among(u"gibel", -1, 1),
        Among(u"ail", -1, 1),
        Among(u"kail", 209, 1),
        Among(u"kan", -1, 1),
        Among(u"tan", -1, 1),
        Among(u"etan", 212, 1),
        Among(u"en", -1, 4),
        Among(u"ren", 214, 2),
        Among(u"garren", 215, 1),
        Among(u"gerren", 215, 1),
        Among(u"urren", 215, 1),
        Among(u"ten", 214, 4),
        Among(u"tzen", 214, 4),
        Among(u"zain", -1, 1),
        Among(u"tzain", 221, 1),
        Among(u"kin", -1, 1),
        Among(u"min", -1, 1),
        Among(u"dun", -1, 1),
        Among(u"asun", -1, 1),
        Among(u"tasun", 226, 1),
        Among(u"aizun", -1, 1),
        Among(u"ondo", -1, 1),
        Among(u"kondo", 229, 1),
        Among(u"go", -1, 1),
        Among(u"ngo", 231, 1),
        Among(u"zio", -1, 1),
        Among(u"ko", -1, 1),
        Among(u"trako", 234, 5),
        Among(u"tako", 234, 1),
        Among(u"etako", 236, 1),
        Among(u"eko", 234, 1),
        Among(u"tariko", 234, 1),
        Among(u"sko", 234, 1),
        Among(u"tuko", 234, 1),
        Among(u"minutuko", 241, 6),
        Among(u"zko", 234, 1),
        Among(u"no", -1, 1),
        Among(u"zino", 244, 1),
        Among(u"ro", -1, 1),
        Among(u"aro", 246, 1),
        Among(u"igaro", 247, -1),
        Among(u"taro", 247, 1),
        Among(u"zaro", 247, 1),
        Among(u"ero", 246, 1),
        Among(u"giro", 246, 1),
        Among(u"oro", 246, 1),
        Among(u"oso", -1, 1),
        Among(u"to", -1, 1),
        Among(u"tto", 255, 1),
        Among(u"zto", 255, 1),
        Among(u"txo", -1, 1),
        Among(u"tzo", -1, 1),
        Among(u"gintzo", 259, 1),
        Among(u"ño", -1, 1),
        Among(u"zp", -1, 1),
        Among(u"ar", -1, 1),
        Among(u"dar", 263, 1),
        Among(u"behar", 263, 1),
        Among(u"zehar", 263, -1),
        Among(u"liar", 263, 1),
        Among(u"tiar", 263, 1),
        Among(u"tar", 263, 1),
        Among(u"tzar", 263, 1),
        Among(u"or", -1, 2),
        Among(u"kor", 271, 1),
        Among(u"os", -1, 1),
        Among(u"ket", -1, 1),
        Among(u"du", -1, 1),
        Among(u"mendu", 275, 1),
        Among(u"ordu", 275, 1),
        Among(u"leku", -1, 1),
        Among(u"buru", -1, 2),
        Among(u"duru", -1, 1),
        Among(u"tsu", -1, 1),
        Among(u"tu", -1, 1),
        Among(u"tatu", 282, 4),
        Among(u"mentu", 282, 1),
        Among(u"estu", 282, 1),
        Among(u"txu", -1, 1),
        Among(u"zu", -1, 1),
        Among(u"tzu", 287, 1),
        Among(u"gintzu", 288, 1),
        Among(u"z", -1, 1),
        Among(u"ez", 290, 1),
        Among(u"eroz", 290, 1),
        Among(u"tz", 290, 1),
        Among(u"koitz", 293, 1)
    ]

    a_2 = [
        Among(u"zlea", -1, 2),
        Among(u"keria", -1, 1),
        Among(u"la", -1, 1),
        Among(u"era", -1, 1),
        Among(u"dade", -1, 1),
        Among(u"tade", -1, 1),
        Among(u"date", -1, 1),
        Among(u"tate", -1, 1),
        Among(u"gi", -1, 1),
        Among(u"ki", -1, 1),
        Among(u"ik", -1, 1),
        Among(u"lanik", 10, 1),
        Among(u"rik", 10, 1),
        Among(u"larik", 12, 1),
        Among(u"ztik", 10, 1),
        Among(u"go", -1, 1),
        Among(u"ro", -1, 1),
        Among(u"ero", 16, 1),
        Among(u"to", -1, 1)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass


class lab4(BaseException): pass


class lab5(BaseException): pass


class lab6(BaseException): pass


class lab7(BaseException): pass
